{"nbformat":4,"nbformat_minor":0,"metadata":{"colab":{"provenance":[]},"kernelspec":{"name":"python3","display_name":"Python 3"},"language_info":{"name":"python"}},"cells":[{"cell_type":"markdown","source":["Created on Thu Sep  6 13:34:32 2018\n","By Simoneta Cano de las Heras\n","\n","Adapted by Mariana Albino, October 2024"],"metadata":{"id":"lNpEVe-IFq-E"}},{"cell_type":"markdown","source":["# Aerobic fermentation model (S. cerevisiae)\n","\n","This model describes an aerobic batch *S. cerevisiae* fermentation. It uses Monod-Herbert expressions to describe the kinetics of the process. It can take into account the metabolic heat produced by the cells, in which case a PID controller is used to maintain a stable temperature"],"metadata":{"id":"p2EXHEfGp956"}},{"cell_type":"markdown","source":["# Package import\n","\n","This portion of the code handles the import of all the relevant python packages."],"metadata":{"id":"Pfafh7qhq1Nf"}},{"cell_type":"code","source":["#import the necesary packages\n","\n","from scipy.integrate import odeint\n","#Package for plotting\n","import math\n","#Package for the use of vectors and matrix\n","import numpy as np\n","import array as arr\n","from matplotlib.figure import Figure\n","import sys\n","import os\n","import matplotlib.pyplot as plt\n","from matplotlib.ticker import FormatStrFormatter\n","import glob\n","from random import sample\n","import random\n","import time\n","import plotly.graph_objects as go\n","import plotly\n","import json\n","import pandas as pd"],"metadata":{"id":"zx05SHbTF8Mh"},"execution_count":null,"outputs":[]},{"cell_type":"markdown","source":["# Model definition\n","\n","The model is defined by using a class. This has several adavantages, one being that different classes can be defined independtly, e.g., one class represents the model definition while another will handle parameter optimization with experimental data. The same \"optimization\" class can be used with different model classes, so the code becomes more easily reusable.\n","\n","The class Monod_Herbert includes several functions, each with a specific function.\n","\n","\n","\n","1.   **_init_** This function initialises the model class by defining all the relavant parameters and initial conditions.\n","2.   **rxn** This function includes all the model equations. The model uses matrix notation to define the ODEs\n","3. **solve** This function generates the timesteps for solving the ODEs. It includes an approach for when the \"CONTROL\" option is turned OFF and an approach that solves a PDI controller for temperature control, for when the \"CONTROL\" feature is ON.\n","4. **create_plot** This function stores the results of the simulation on a dataframe which is used for plotting all relevant variables.\n","\n"],"metadata":{"id":"-YufqxWUq-yv"}},{"cell_type":"code","source":["class Monod_Herbert:\n","  #initialise the model\n","    def __init__(self, Control=False):  #change to Control=True if you want to see the effect of Temperature control\n","         # define value of model parameters\n","        self.Y_XS = 0.8\n","        self.Y_OX = 1.05\n","        self.y_x = 0.5\n","        self.mu_max = 1.1\n","        self.Ks = 0.17\n","        self.kd = 0.08\n","        self.kla = 1004\n","        self.O_sat = 0.0755\n","\n","        #define initial conditions\n","        self.G0 = 18\n","        self.O0 = 0.0755\n","        self.X0 = 0.01\n","        self.V0 = 40\n","\n","        #define parameters for control, default every 1/24 hours:\n","        self.t_end = 30\n","        self.t_start = 0\n","        self.Control = False\n","        self.coolingOn = True\n","        self.steps = (self.t_end - self.t_start)*24\n","        self.T0 = 30\n","        self.K_p = 2.31e+01\n","        self.K_i = 3.03e-01\n","        self.K_d = -3.58e-03\n","        self.Tset = 30\n","        self.u_max = 150\n","        self.u_min = 1\n","\n","\n","\n","\n","    #define the stoichiometric matrix\n","    def rxn(self, C,t, u):\n","        #when there is no control, k has no effect\n","        k=1\n","        #when cooling is off than u = 0\n","        if self.coolingOn == False:\n","            u = 0  #flow of cooling water\n","      #define temperature controller\n","        if self.Control == True :\n","            #Cardinal temperature model with inflection: Salvado et al 2011 \"Temperature Adaptation Markedly Determines Evolution within the Genus Saccharomyces\"\n","            #Strain S. cerevisiae PE35 M\n","\n","            #How is the growth rate of the organism affected by the changes in temperature\n","            Topt = 30\n","            Tmax = 45.48\n","            Tmin = 5.04\n","            T = C[4]\n","            if T < Tmin or T > Tmax:\n","                 k = 0  #growth rate\n","            else:\n","                 D = (T-Tmax)*(T-Tmin)**2\n","                 E = (Topt-Tmin)*((Topt-Tmin)*(T-Topt)-(Topt-Tmax)*(Topt+Tmin-2*T))\n","                 k = D/E\n","\n","        #number of components\n","        n = 3\n","        m = 3\n","        #initialize the stoichiometric matrix, s\n","        s = np.zeros((m,n))\n","        s[0,0] = -1/self.Y_XS\n","        s[0,1] = -1/self.Y_OX\n","        s[0,2] = 1\n","\n","\n","        s[1,0] = 0\n","        s[1,1] = 1/self.y_x\n","        s[1,2] = -1\n","\n","        s[2,0] = 0\n","        s[2,1] = self.kla\n","        s[2,2] = 0\n","        #initialize the rate vector\n","        rho = np.zeros((m,1))\n","        ##initialize the overall conversion vector\n","        r=np.zeros((n,1))\n","        rho[0,0] = self.mu_max*(C[0]/(C[0]+self.Ks))*C[2]\n","        rho[1,0] = self.kd*C[2]\n","        rho[2,0] = self.kla*(self.O_sat - C[1])\n","\n","        #Developing the matrix, the overall conversion rate is stoichiometric *rates\n","        r[0,0] = (s[0,0]*rho[0,0])+(s[1,0]*rho[1,0])+(s[2,0]*rho[2,0])\n","        r[1,0] = (s[0,1]*rho[0,0])+(s[1,1]*rho[1,0])+(s[2,1]*rho[2,0])\n","        r[2,0] = (s[0,2]*rho[0,0])+(s[1,2]*rho[1,0])+(s[2,2]*rho[2,0])\n","\n","\n","        #Solving the mass balances\n","        dSdt = r[0,0]\n","        dOdt = r[1,0]\n","        dXdt = r[2,0]\n","        dVdt = 0\n","        if self.Control == True :\n","            '''\n","\n","             dHrxn heat produced by cells estimated by yeast heat combustion coeficcient dhc0 = -21.2 kJ/g\n","\n","             dHrxn = dGdt*V*dhc0(G)-dEdt*V*dhc0(E)-dXdt*V*dhc0(X)\n","\n","             (when cooling is working)  Q = - dHrxn -W ,\n","\n","             dT = V[L] * 1000 g/L / 4.1868 [J/gK]*dE [kJ]*1000 J/KJ\n","\n","             dhc0(EtOH) = -1366.8 kJ/gmol/46 g/gmol [KJ/g]\n","\n","             dhc0(Glc) = -2805 kJ/gmol/180g/gmol [KJ/g]\n","\n","\n","\n","            '''\n","            #Metabolic heat: [W]=[J/s], dhc0 from book \"Bioprocess Engineering Principles\" (Pauline M. Doran) : Appendix Table C.8\n","            dHrxndt =   dXdt*C[4]*(-21200) #[J/s]\n","            #Shaft work 1 W/L1\n","            W = -1*C[4] #[J/S] negative because exothermic\n","\n","\n","            #Mass flow cooling water\n","            M=u/3600*1000 #[kg/s]\n","            #Define Tin = 5 C, Tout=TReactor\n","            #heat capacity water = 4190 J/kgK\n","            Tin = 5\n","            #Estimate water at outlet same as Temp in reactor\n","            Tout = C[4]\n","            cpc = 4190\n","            #Calculate Q from Eq 9.47\n","            Q=-M*cpc*(Tout-Tin) # J/s\n","            #Calculate Temperature change\n","            dTdt = -1*(dHrxndt - Q + W)/(C[4]*1000*4.1868) #[K/s]\n","        else:\n","            dTdt = 0\n","        return [dSdt, dOdt, dXdt, dVdt, dTdt]\n","\n","\n","    def solve(self):\n","\n","        t = np.linspace(self.t_start, self.t_end, self.steps) #generation of the time-points\n","\n","        #solve if Control is OFF:\n","        if self.Control == False :\n","            u = 0\n","            C0 = [self.G0,  self.O0, self.X0,self.V0, self.T0]   #initial conditions vector\n","            C = odeint(self.rxn, C0, t, rtol = 1e-7, mxstep= 500000, args=(u,)) #solve ODEs\n","\n","        #solve for Control ON\n","        else:\n","            \"\"\"\n","\n","            PID Temperature Control:\n","\n","            \"\"\"\n","            # storage for recording values\n","            C = np.ones([len(t), 5])\n","            C0 = [self.G0, self.O0, self.X0,self.V0,self.T0]\n","            self.ctrl_output = np.zeros(len(t)) # controller output\n","            e = np.zeros(len(t)) # error\n","            ie = np.zeros(len(t)) # integral of the error\n","            dpv = np.zeros(len(t)) # derivative of the pv\n","            P = np.zeros(len(t)) # proportional\n","            I = np.zeros(len(t)) # integral\n","            D = np.zeros(len(t)) # derivative\n","\n","            for i in range(len(t)-1):\n","\n","                #PID control of cooling water\n","                dt = t[i+1]-t[i]\n","                #Error\n","                e[i] = C[i,4] - self.Tset\n","                #print(e[i])\n","                if i >= 1:\n","                    dpv[i] = (C[i,4]-C[i-1,4])/dt\n","                    ie[i] = ie[i-1] + e[i] * dt\n","\n","                #print(ie)\n","                P[i]=self.K_p*e[i]\n","                I[i]=self.K_i*ie[i]\n","                D[i]=self.K_d*dpv[i]\n","\n","                self.ctrl_output[i]=P[i]+I[i]+D[i]\n","                u=self.ctrl_output[i]\n","\n","                #print(u)\n","                if u>self.u_max:\n","                    u=self.u_max\n","                    ie[i] = ie[i] - e[i]*dt # anti-reset windup\n","\n","                if u < self.u_min:\n","                    u =self.u_min\n","                    ie[i] = ie[i] - e[i]*dt # anti-reset windup\n","\n","                #print(u)\n","\n","                if i > 0 and e[i] * e[i-1] < 0:\n","                  ie[i] = 0\n","                #time for solving ODE\n","                ts = [t[i],t[i+1]]\n","\n","                #solve ODE from last timepoint to new timepoint with old values\n","\n","                y =  odeint(self.rxn, C0, ts, rtol = 1e-7, mxstep= 500000, args=(u,))\n","                #update C0\n","                C0 = y[-1]\n","                #merge y to C\n","                C[i+1]=y[-1]\n","\n","        return t, C\n","\n","    #generate the plot of model variables\n","\n","    def create_plot(self, t, C):\n","        G = C[:, 0]\n","        O = C[:, 1]\n","        B = C[:, 2]\n","        T = C[:, 4]\n","        df = pd.DataFrame({'t': t, 'Substrate': G, 'Biomass': B, 'Oxygen': O, 'Temperature' :T})\n","        fig = go.Figure()\n","        fig.add_trace(go.Scatter(x=df['t'], y=df['Substrate'], name='Substrate'))\n","        fig.add_trace(go.Scatter(x=df['t'], y=df['Biomass'], name='Biomass'))\n","        fig.add_trace(go.Scatter(x=df['t'], y=df['Oxygen'], name='Oxygen'))\n","        fig.update_layout(                          xaxis_title='time (h)',\n","                          yaxis_title='Concentration (g/L)')\n","        figT =go.Figure()\n","        figT.add_trace(go.Scatter(x=df['t'], y=df['Temperature'], name='Temperature'))\n","        figT.update_layout(xaxis_title='time (h)',\n","                          yaxis_title='Temperature (C)')\n","\n","\n","\n","        return fig, figT"],"metadata":{"id":"voX_Oe83IDvE"},"execution_count":null,"outputs":[]},{"cell_type":"markdown","source":["# Extract results and make plots\n","\n","This portion of the code extracts the results from the Monod_Herbert class and creates the figures to display the simulation results."],"metadata":{"id":"_pJeig_drCtY"}},{"cell_type":"code","source":["model = Monod_Herbert() # Instantiate the Monod_Herbert class\n","t, C = model.solve() # Call the solve method to get the simulation results\n","fig = model.create_plot(t, C)[0] # Call create_plot with the simulation results\n","figT = model.create_plot(t, C)[1] # Call create_plot with the simulation results\n","\n","fig.show()\n","figT.show()"],"metadata":{"colab":{"base_uri":"https://localhost:8080/","height":1000},"id":"k2s7hJIkNKpS","executionInfo":{"status":"ok","timestamp":1730295329675,"user_tz":-60,"elapsed":18,"user":{"displayName":"Mariana Albino","userId":"14583712435379609229"}},"outputId":"c52ff5eb-e703-4cdc-b4b1-4c7cb410fa2c"},"execution_count":null,"outputs":[{"output_type":"display_data","data":{"text/html":["<html>\n","<head><meta charset=\"utf-8\" /></head>\n","<body>\n","    <div>            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax && window.MathJax.Hub && window.MathJax.Hub.Config) {window.MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n","        <script charset=\"utf-8\" src=\"https://cdn.plot.ly/plotly-2.35.2.min.js\"></script>                <div id=\"e12d655d-7666-4f6b-96b9-fff07e0c2bd9\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"e12d655d-7666-4f6b-96b9-fff07e0c2bd9\")) {                    Plotly.newPlot(                        \"e12d655d-7666-4f6b-96b9-fff07e0c2bd9\",                        [{\"name\":\"Substrate\",\"x\":[0.0,0.04172461752433936,0.08344923504867872,0.12517385257301808,0.16689847009735745,0.20862308762169682,0.25034770514603616,0.29207232267037553,0.3337969401947149,0.37552155771905427,0.41724617524339364,0.458970792767733,0.5006954102920723,0.5424200278164117,0.5841446453407511,0.6258692628650905,0.6675938803894298,0.7093184979137691,0.7510431154381085,0.7927677329624478,0.8344923504867873,0.8762169680111266,0.917941585535466,0.9596662030598053,1.0013908205841446,1.043115438108484,1.0848400556328235,1.1265646731571628,1.1682892906815021,1.2100139082058414,1.251738525730181,1.2934631432545203,1.3351877607788596,1.376912378303199,1.4186369958275382,1.4603616133518778,1.502086230876217,1.5438108484005564,1.5855354659248957,1.6272600834492352,1.6689847009735745,1.7107093184979139,1.7524339360222532,1.7941585535465925,1.835883171070932,1.8776077885952713,1.9193324061196106,1.96105702364395,2.0027816411682893,2.044506258692629,2.086230876216968,2.1279554937413074,2.169680111265647,2.211404728789986,2.2531293463143256,2.294853963838665,2.3365785813630042,2.3783031988873438,2.420027816411683,2.4617524339360224,2.503477051460362,2.545201668984701,2.5869262865090406,2.6286509040333796,2.670375521557719,2.7121001390820587,2.753824756606398,2.7955493741307373,2.8372739916550764,2.878998609179416,2.9207232267037555,2.9624478442280946,3.004172461752434,3.0458970792767732,3.0876216968011128,3.1293463143254523,3.1710709318497914,3.212795549374131,3.2545201668984705,3.2962447844228095,3.337969401947149,3.379694019471488,3.4214186369958277,3.4631432545201672,3.5048678720445063,3.546592489568846,3.588317107093185,3.6300417246175245,3.671766342141864,3.713490959666203,3.7552155771905427,3.7969401947148818,3.8386648122392213,3.880389429763561,3.9221140472879,3.9638386648122395,4.0055632823365785,4.047287899860918,4.089012517385258,4.130737134909597,4.172461752433936,4.214186369958275,4.255910987482615,4.297635605006954,4.339360222531294,4.381084840055633,4.422809457579972,4.464534075104312,4.506258692628651,4.547983310152991,4.58970792767733,4.631432545201669,4.6731571627260085,4.714881780250348,4.7566063977746875,4.798331015299027,4.840055632823366,4.881780250347705,4.923504867872045,4.965229485396384,5.006954102920724,5.0486787204450625,5.090403337969402,5.132127955493742,5.173852573018081,5.215577190542421,5.257301808066759,5.299026425591099,5.340751043115438,5.382475660639778,5.424200278164117,5.465924895688456,5.507649513212796,5.549374130737135,5.591098748261475,5.632823365785814,5.674547983310153,5.716272600834492,5.757997218358832,5.7997218358831715,5.841446453407511,5.88317107093185,5.924895688456189,5.966620305980529,6.008344923504868,6.050069541029208,6.0917941585535464,6.133518776077886,6.1752433936022255,6.216968011126565,6.258692628650905,6.300417246175244,6.342141863699583,6.383866481223922,6.425591098748262,6.467315716272601,6.509040333796941,6.55076495132128,6.592489568845619,6.634214186369959,6.675938803894298,6.717663421418638,6.759388038942976,6.801112656467316,6.842837273991655,6.884561891515995,6.9262865090403345,6.968011126564673,7.009735744089013,7.051460361613352,7.093184979137692,7.134909596662031,7.17663421418637,7.2183588317107095,7.260083449235049,7.3018080667593885,7.343532684283728,7.385257301808067,7.426981919332406,7.468706536856746,7.510431154381085,7.552155771905425,7.5938803894297635,7.635605006954103,7.677329624478443,7.719054242002782,7.760778859527122,7.80250347705146,7.8442280945758,7.885952712100139,7.927677329624479,7.969401947148818,8.011126564673157,8.052851182197497,8.094575799721836,8.136300417246176,8.178025034770515,8.219749652294855,8.261474269819194,8.303198887343534,8.344923504867872,8.386648122392211,8.42837273991655,8.47009735744089,8.51182197496523,8.55354659248957,8.595271210013909,8.636995827538248,8.678720445062588,8.720445062586927,8.762169680111265,8.803894297635605,8.845618915159944,8.887343532684284,8.929068150208623,8.970792767732963,9.012517385257302,9.054242002781642,9.095966620305981,9.137691237830321,9.17941585535466,9.221140472878998,9.262865090403338,9.304589707927677,9.346314325452017,9.388038942976356,9.429763560500696,9.471488178025036,9.513212795549375,9.554937413073715,9.596662030598054,9.638386648122392,9.680111265646731,9.721835883171071,9.76356050069541,9.80528511821975,9.84700973574409,9.888734353268429,9.930458970792769,9.972183588317108,10.013908205841448,10.055632823365785,10.097357440890125,10.139082058414465,10.180806675938804,10.222531293463144,10.264255910987483,10.305980528511823,10.347705146036162,10.389429763560502,10.431154381084841,10.472878998609179,10.514603616133519,10.556328233657858,10.598052851182198,10.639777468706537,10.681502086230877,10.723226703755216,10.764951321279556,10.806675938803895,10.848400556328235,10.890125173852574,10.931849791376912,10.973574408901252,11.015299026425591,11.05702364394993,11.09874826147427,11.14047287899861,11.18219749652295,11.223922114047289,11.265646731571628,11.307371349095968,11.349095966620306,11.390820584144645,11.432545201668985,11.474269819193324,11.515994436717664,11.557719054242003,11.599443671766343,11.641168289290682,11.682892906815022,11.724617524339362,11.7663421418637,11.808066759388039,11.849791376912378,11.891515994436718,11.933240611961057,11.974965229485397,12.016689847009737,12.058414464534076,12.100139082058416,12.141863699582755,12.183588317107093,12.225312934631432,12.267037552155772,12.308762169680111,12.350486787204451,12.39221140472879,12.43393602225313,12.47566063977747,12.51738525730181,12.559109874826149,12.600834492350488,12.642559109874826,12.684283727399166,12.726008344923505,12.767732962447845,12.809457579972184,12.851182197496524,12.892906815020863,12.934631432545203,12.976356050069542,13.018080667593882,13.05980528511822,13.10152990264256,13.143254520166899,13.184979137691238,13.226703755215578,13.268428372739917,13.310152990264257,13.351877607788596,13.393602225312936,13.435326842837275,13.477051460361613,13.518776077885953,13.560500695410292,13.602225312934632,13.643949930458971,13.68567454798331,13.72739916550765,13.76912378303199,13.81084840055633,13.852573018080669,13.894297635605007,13.936022253129346,13.977746870653686,14.019471488178025,14.061196105702365,14.102920723226704,14.144645340751044,14.186369958275383,14.228094575799723,14.269819193324063,14.311543810848402,14.35326842837274,14.39499304589708,14.436717663421419,14.478442280945758,14.520166898470098,14.561891515994438,14.603616133518777,14.645340751043117,14.687065368567456,14.728789986091796,14.770514603616133,14.812239221140473,14.853963838664813,14.895688456189152,14.937413073713492,14.979137691237831,15.02086230876217,15.06258692628651,15.10431154381085,15.14603616133519,15.187760778859527,15.229485396383867,15.271210013908206,15.312934631432546,15.354659248956885,15.396383866481225,15.438108484005564,15.479833101529904,15.521557719054243,15.563282336578583,15.60500695410292,15.64673157162726,15.6884561891516,15.73018080667594,15.771905424200279,15.813630041724618,15.855354659248958,15.897079276773297,15.938803894297637,15.980528511821976,16.022253129346314,16.063977746870655,16.105702364394993,16.147426981919335,16.189151599443672,16.230876216968014,16.27260083449235,16.31432545201669,16.35605006954103,16.39777468706537,16.43949930458971,16.481223922114047,16.52294853963839,16.564673157162726,16.606397774687068,16.648122392211405,16.689847009735743,16.731571627260085,16.773296244784422,16.815020862308764,16.8567454798331,16.898470097357443,16.94019471488178,16.98191933240612,17.02364394993046,17.0653685674548,17.10709318497914,17.148817802503476,17.190542420027818,17.232267037552155,17.273991655076497,17.315716272600834,17.357440890125176,17.399165507649514,17.440890125173855,17.482614742698193,17.52433936022253,17.56606397774687,17.60778859527121,17.64951321279555,17.69123783031989,17.73296244784423,17.774687065368568,17.81641168289291,17.858136300417247,17.899860917941588,17.941585535465926,17.983310152990263,18.025034770514605,18.066759388038943,18.108484005563284,18.15020862308762,18.191933240611963,18.2336578581363,18.275382475660642,18.31710709318498,18.35883171070932,18.40055632823366,18.442280945757997,18.484005563282338,18.525730180806676,18.567454798331017,18.609179415855355,18.650904033379696,18.692628650904034,18.734353268428375,18.776077885952713,18.81780250347705,18.859527121001392,18.90125173852573,18.94297635605007,18.98470097357441,19.02642559109875,19.068150208623088,19.10987482614743,19.151599443671767,19.19332406119611,19.235048678720446,19.276773296244784,19.318497913769125,19.360222531293463,19.401947148817804,19.443671766342142,19.485396383866483,19.52712100139082,19.568845618915162,19.6105702364395,19.65229485396384,19.69401947148818,19.735744089012517,19.777468706536858,19.819193324061196,19.860917941585537,19.902642559109875,19.944367176634216,19.986091794158554,20.027816411682895,20.069541029207233,20.11126564673157,20.152990264255912,20.19471488178025,20.23643949930459,20.27816411682893,20.31988873435327,20.361613351877608,20.40333796940195,20.445062586926287,20.48678720445063,20.528511821974966,20.570236439499304,20.611961057023645,20.653685674547983,20.695410292072324,20.737134909596662,20.778859527121003,20.82058414464534,20.862308762169683,20.90403337969402,20.945757997218358,20.9874826147427,21.029207232267037,21.07093184979138,21.112656467315716,21.154381084840058,21.196105702364395,21.237830319888737,21.279554937413074,21.321279554937416,21.363004172461753,21.40472878998609,21.446453407510432,21.48817802503477,21.52990264255911,21.57162726008345,21.61335187760779,21.65507649513213,21.69680111265647,21.738525730180807,21.78025034770515,21.821974965229487,21.863699582753824,21.905424200278166,21.947148817802503,21.988873435326845,22.030598052851182,22.072322670375524,22.11404728789986,22.155771905424203,22.19749652294854,22.23922114047288,22.28094575799722,22.322670375521557,22.3643949930459,22.406119610570236,22.447844228094578,22.489568845618916,22.531293463143257,22.573018080667595,22.614742698191936,22.656467315716274,22.69819193324061,22.739916550764953,22.78164116828929,22.823365785813632,22.86509040333797,22.90681502086231,22.94853963838665,22.99026425591099,23.031988873435328,23.073713490959666,23.115438108484007,23.157162726008345,23.198887343532686,23.240611961057024,23.282336578581365,23.324061196105703,23.365785813630044,23.407510431154382,23.449235048678723,23.49095966620306,23.5326842837274,23.57440890125174,23.616133518776078,23.65785813630042,23.699582753824757,23.741307371349098,23.783031988873436,23.824756606397777,23.866481223922115,23.908205841446456,23.949930458970794,23.99165507649513,24.033379694019473,24.07510431154381,24.116828929068152,24.15855354659249,24.20027816411683,24.24200278164117,24.28372739916551,24.325452016689848,24.367176634214186,24.408901251738527,24.450625869262865,24.492350486787206,24.534075104311544,24.575799721835885,24.617524339360223,24.659248956884564,24.700973574408902,24.742698191933243,24.78442280945758,24.82614742698192,24.86787204450626,24.909596662030598,24.95132127955494,24.993045897079277,25.03477051460362,25.076495132127956,25.118219749652297,25.159944367176635,25.201668984700976,25.243393602225314,25.285118219749652,25.326842837273993,25.36856745479833,25.410292072322672,25.45201668984701,25.49374130737135,25.53546592489569,25.57719054242003,25.61891515994437,25.660639777468706,25.702364394993047,25.744089012517385,25.785813630041726,25.827538247566064,25.869262865090406,25.910987482614743,25.952712100139085,25.994436717663422,26.036161335187764,26.0778859527121,26.11961057023644,26.16133518776078,26.20305980528512,26.24478442280946,26.286509040333797,26.32823365785814,26.369958275382476,26.411682892906818,26.453407510431155,26.495132127955493,26.536856745479835,26.578581363004172,26.620305980528514,26.66203059805285,26.703755215577193,26.74547983310153,26.78720445062587,26.82892906815021,26.87065368567455,26.91237830319889,26.954102920723226,26.995827538247568,27.037552155771905,27.079276773296247,27.121001390820584,27.162726008344926,27.204450625869264,27.246175243393605,27.287899860917943,27.329624478442284,27.37134909596662,27.41307371349096,27.4547983310153,27.49652294853964,27.53824756606398,27.579972183588318,27.62169680111266,27.663421418636997,27.705146036161338,27.746870653685676,27.788595271210013,27.830319888734355,27.872044506258693,27.913769123783034,27.95549374130737,27.997218358831713,28.03894297635605,28.080667593880392,28.12239221140473,28.16411682892907,28.20584144645341,28.247566063977747,28.289290681502088,28.331015299026426,28.372739916550767,28.414464534075105,28.456189151599446,28.497913769123784,28.539638386648125,28.581363004172463,28.623087621696804,28.664812239221142,28.70653685674548,28.74826147426982,28.78998609179416,28.8317107093185,28.873435326842838,28.91515994436718,28.956884561891517,28.99860917941586,29.040333796940196,29.082058414464534,29.123783031988875,29.165507649513213,29.207232267037554,29.248956884561892,29.290681502086233,29.33240611961057,29.374130737134912,29.41585535465925,29.45757997218359,29.49930458970793,29.541029207232267,29.582753824756608,29.624478442280946,29.666203059805287,29.707927677329625,29.749652294853966,29.791376912378304,29.833101529902645,29.874826147426983,29.91655076495132,29.958275382475662,30.0],\"y\":[18.0,17.999419483021576,17.998814010349673,17.99818249414982,17.997523797159246,17.996836753326473,17.996120146032563,17.995372700613274,17.994593099628684,17.99377995919068,17.99293183338754,17.992047210652263,17.99112452125017,17.990162126457886,17.989158316128115,17.988111309912803,17.987019254548056,17.98588021005326,17.98469215347539,17.983452978528746,17.982160481206396,17.98081237113702,17.979406252424088,17.977939630053072,17.97640990268625,17.974814350480276,17.973150149090458,17.971414343332516,17.969603851699276,17.96771546267986,17.96574581902021,17.9636914259826,17.961548635018776,17.95931364215328,17.956982482515485,17.954551017379636,17.952014933673926,17.949369729481408,17.946610710939954,17.94373298067248,17.940731431437634,17.937600735332182,17.934335336494623,17.93092943747671,17.927376994477104,17.923671705208612,17.91980698872791,17.915775993310223,17.911571559992854,17.907186229864884,17.902612223782004,17.8978414182356,17.892865354912278,17.887675196296307,17.882261736320856,17.876615371038405,17.870726074363777,17.86458340601861,17.858176455865337,17.851493863124215,17.84452377231818,17.837253809056815,17.829671087207576,17.82176213894282,17.813512943709572,17.804908866651147,17.795934635978252,17.78657434568767,17.776811373696233,17.766628415695404,17.756007407323455,17.74492950184687,17.733375067793354,17.721323599471923,17.708753733464942,17.695643169163205,17.681968663459614,17.667705958806422,17.652829772670007,17.637313719807043,17.621130298183676,17.604250809893742,17.586645336826923,17.568282666202204,17.549130251640346,17.529154144817415,17.508318941710122,17.486587718878706,17.4639219650978,17.44028152184367,17.415624498938644,17.389907220062728,17.36308412074682,17.335107699286496,17.305928396189923,17.27549455008592,17.243752258017896,17.21064533591088,17.176115158727132,17.140100625474787,17.102537978385026,17.063360771395075,17.022499665557138,16.979882403555983,16.93543358215873,16.889074627789288,16.840723546068574,16.79029489954626,16.73769953125074,16.682844544761227,16.625633000934226,16.565963897155424,16.503731844439475,16.43882702836388,16.371134887457718,16.300536032730996,16.22690594278852,16.15011483239213,16.07002736619874,15.986502473406818,15.89939308071976,15.808545870257616,15.713801031969602,15.614991962489917,15.51194503667717,15.404479245695299,15.292405986828728,15.175528639825613,15.053642373486408,14.92653366046251,14.793980098168403,14.655749863977281,14.511601546695683,14.361283546623179,14.204533912067502,14.041079692395812,13.870636771626067,13.692909188036705,13.507588953340317,13.314355360665163,13.112874772573594,12.902799951996908,12.683769794298358,12.455408735593887,12.217326391732822,11.969117131460727,11.710359570204123,11.440616509296694,11.159434074359725,10.866341753517816,10.560852523513933,10.242462303986624,9.910650480864874,9.564879533403058,9.204597116744916,8.829236036483783,8.438216174635686,8.030947145634126,7.606832105620494,7.165272954829071,6.705678861991006,6.22747851028037,5.730137913505881,5.213189007558321,4.676277254061754,4.119237894175023,3.5422367122052387,2.9460365193129547,2.332565669122931,1.706298954334512,1.0783577274179674,0.4830336374655855,0.06649978075863425,0.0011071967022668002,1.2771874814599925e-05,1.5353943280992514e-07,6.806055029827185e-09,1.0207933952843223e-09,-6.407866991094563e-10,-9.809540784836956e-11,-1.035371954062944e-09,1.7452137702348177e-10,-2.1530176990668666e-10,-3.353534710217453e-10,-1.4729241861449392e-10,-1.2616118928529e-11,3.8251712297382045e-11,3.5105780264190884e-10,7.240187602197388e-10,9.53500781807425e-10,9.44804837898474e-10,6.03231898986394e-10,1.9996045438694487e-10,1.9827102666476948e-10,1.658445750695209e-10,9.449998656508514e-11,-2.3943851884651574e-11,-1.9601973859360932e-10,-2.4714104383550453e-10,-2.7535043602999585e-10,-2.7404034060339846e-10,-2.3660318298202673e-10,-1.5643138859219462e-10,-1.2652756724208718e-10,-6.62966749189021e-11,-1.8077788130046046e-11,2.1197404576613287e-11,5.2935048042340666e-11,8.006768019613002e-11,1.1162616689373528e-10,1.381914720044648e-10,1.5624565363437975e-10,1.6074927455578614e-10,1.4514140220724012e-10,1.0133960869354659e-10,4.367964376582437e-11,4.759543297859939e-11,5.44602637128957e-11,6.352650712297364e-11,7.362049787847303e-11,8.314253416441322e-11,9.006687768119288e-11,9.470032181769846e-11,1.0467734714372233e-10,1.111310434816571e-10,1.1193642339675563e-10,1.0467355061183756e-10,8.662754000728929e-11,5.478855762106403e-11,1.4847186263384728e-11,-6.304834781756602e-13,-1.4607984536554337e-11,-2.583670594963294e-11,-3.2918487836816026e-11,-3.4305621399033615e-11,-2.8300848918740498e-11,-1.7015878453038603e-11,-1.5264577093918287e-11,-1.2069151550613067e-11,-7.62452055533776e-12,-2.1797450799179424e-12,3.9619716642097295e-12,1.0443284225998631e-11,1.7303550679645178e-11,2.5820543703767425e-11,3.4104829680258646e-11,4.169488202878436e-11,4.808111708875381e-11,5.2705894119319924e-11,5.496351529937938e-11,5.4200225727572627e-11,4.9714213422284095e-11,4.0755609321641344e-11,2.6526487283516125e-11,6.777694851719224e-12,3.2896777788496353e-12,-4.955156066268874e-13,-4.51001108026695e-12,-8.676154458649602e-12,-1.2906511599376448e-11,-1.7103868401071578e-11,-2.11612308033816e-11,-2.4961824786975466e-11,-2.8379096373545127e-11,-3.127671162580454e-11,-3.350855664749034e-11,-3.594965596385566e-11,-3.79444934434019e-11,-3.92216397471505e-11,-3.965360288976544e-11,-3.9106131307266634e-11,-3.7438213857029914e-11,-3.4502079817787274e-11,-3.014319888962621e-11,-2.4200281193990554e-11,-1.6505277273679967e-11,-6.8833780928500735e-12,2.2419210940490793e-13,5.54644255812701e-12,1.083373321954312e-11,1.5955781419055695e-11,2.0771529526966835e-11,2.5129144958478043e-11,2.8866020173691003e-11,3.180877267760643e-11,3.3773245020124835e-11,3.456450479604635e-11,3.3976844645070716e-11,3.2566213192509804e-11,3.314076457345067e-11,3.279097618268719e-11,3.146925971145971e-11,2.911925006158539e-11,2.567660405561092e-11,2.1069799146966108e-11,1.5220932130116656e-11,8.046517850717277e-12,-5.417120842352027e-13,-1.06360105962488e-11,-1.998768126925669e-11,-2.5148292775582225e-11,-3.040761904980947e-11,-3.568958244504457e-11,-4.090826103544059e-11,-4.596685263197393e-11,-5.075663879821876e-11,-5.515594886612369e-11,-5.902912395178743e-11,-6.222548097123435e-11,-6.457827665619042e-11,-6.59036715698589e-11,-6.599969412269602e-11,-6.464520458818689e-11,-6.159885911862134e-11,-5.6598073760869164e-11,-4.935798847215655e-11,-3.957043113584146e-11,-2.690288157718951e-11,-1.0997435579149695e-11,-6.345760146933575e-12,-5.966548835689025e-12,-5.709522354562435e-12,-5.5721872206098e-12,-5.547209991008886e-12,-5.621995386271064e-12,-5.778264413453217e-12,-5.991632489369667e-12,-6.231187563804004e-12,-6.4590682427210575e-12,-6.630041911478723e-12,-6.6910828580399e-12,-6.580950396184359e-12,-6.229766988720651e-12,-5.558596370698035e-12,-4.4790216726182435e-12,-2.8927235436475448e-12,-6.910582748285312e-13,2.245364077707948e-12,5.0504407988518286e-12,4.2390302285995036e-12,3.4148038026843547e-12,2.621872109915147e-12,1.9103410466967167e-12,1.336567688469837e-12,9.634161611511945e-13,8.605135125735588e-13,1.104505583925675e-12,1.779312881192401e-12,2.976386446594703e-12,4.794963730029677e-12,7.342324460510557e-12,1.0734046517606822e-11,1.5094261802884128e-11,2.0555912111344414e-11,2.7261005002865596e-11,3.536086967364277e-11,4.501641282762658e-11,5.639837454796428e-11,6.568376530414764e-11,7.342820005921392e-11,8.161075415483239e-11,9.021238486727731e-11,9.92096084384252e-11,1.0857430442423133e-10,1.1827352004320572e-10,1.2826927452489117e-10,1.3851836345833728e-10,1.4897216314057846e-10,1.5957643492511e-10,1.702711295703645e-10,1.8099019158818823e-10,1.916613635923176e-10,2.022059906468557e-10,2.1253882461474847e-10,2.2105175125910563e-10,2.281357198686354e-10,2.340976377412221e-10,2.3874805133184136e-10,2.418848595753225e-10,2.4329297128450395e-10,2.4274396254838805e-10,2.3999573413029597e-10,2.347921688660229e-10,2.26862789061993e-10,2.15922413893415e-10,2.0167081680243452e-10,1.8379238289629513e-10,1.619557663454841e-10,1.3581354778189949e-10,1.0500189169699024e-10,7.921324696551106e-11,5.2992899448135426e-11,2.4511415917413762e-11,-6.220584646952e-12,-3.9181043773230215e-11,-7.43359524533286e-11,-1.1163884009850753e-10,-1.510302634950461e-10,-1.9243729575995834e-10,-2.357730152966566e-10,-2.809359947506661e-10,-3.278097899653058e-10,-3.7626242893736586e-10,-4.2614590077282643e-10,-4.77295644642515e-10,-5.295300387378311e-10,-5.732073728113716e-10,-6.141920858236018e-10,-6.525833464764206e-10,-6.877554496742029e-10,-7.190384461889038e-10,-7.457169225597055e-10,-7.670287809926292e-10,-7.821640192601545e-10,-7.902635106008555e-10,-7.904177836190132e-10,-7.816658021842448e-10,-7.629937453311271e-10,-7.333337871588142e-10,-6.915628767306734e-10,-6.36501517973894e-10,-5.674279218519129e-10,-5.121956018185394e-10,-4.476768802305059e-10,-3.7347060793631505e-10,-2.89182929533239e-10,-1.944281277646644e-10,-8.882946791732415e-11,2.7979957781347915e-11,1.563563857659957e-10,2.9664453673597454e-10,4.4917677125813114e-10,6.142722453694862e-10,7.92236066179897e-10,9.833584474748675e-10,1.1879138653181368e-09,1.4061602136545178e-09,1.6328425710843833e-09,1.8240419278194313e-09,2.015342702476752e-09,2.2051024213380107e-09,2.391532810990091e-09,2.5726952693624814e-09,2.7464963367644944e-09,2.9106831669224944e-09,3.062838998017274e-09,3.200378623721211e-09,3.3205438642356454e-09,3.4203990373280554e-09,3.4968264293694103e-09,3.5465217663713763e-09,3.5659896850236373e-09,3.5515392037311343e-09,3.5125725956894675e-09,3.4907516357627748e-09,3.439031152598249e-09,3.3547272790357096e-09,3.235048641443874e-09,3.077094716432668e-09,2.8778541875656896e-09,2.6342033020724746e-09,2.3429042275610078e-09,2.0006034087299684e-09,1.6038299240811436e-09,1.1489938426319273e-09,6.323845806274487e-10,5.016925825325558e-11,-6.01608943652659e-10,-1.3270324268870844e-09,-2.130310819169661e-09,-3.0157826174300104e-09,-3.956843742709385e-09,-4.737157314156826e-09,-5.549069177676832e-09,-6.390174133356846e-09,-7.2577636323343465e-09,-8.148815919239271e-09,-9.059986174635354e-09,-9.987596657462631e-09,-1.0927626847478747e-08,-1.1875703587701505e-08,-1.2827091226850136e-08,-1.3776681761787785e-08,-1.4718984979963174e-08,-1.5648118601852296e-08,-1.6557798423400874e-08,-1.7441328458465654e-08,-1.829159108125694e-08,-1.9101037168779906e-08,-1.985931779205913e-08,-2.0494350610560864e-08,-2.104753872113185e-08,-2.1507727880674554e-08,-2.1863174962150864e-08,-2.2101535267960807e-08,-2.2209849843321447e-08,-2.2174532789645884e-08,-2.1981358577922108e-08,-2.161544936209186e-08,-2.1061262292429704e-08,-2.030257682892164e-08,-1.932248205464442e-08,-1.810336398914404e-08,-1.6626892901814743e-08,-1.4874010625278393e-08,-1.2824917868762447e-08,-1.0459061531480058e-08,-7.75512201600758e-09,-5.421197725429118e-09,-2.912908470494474e-09,-1.9460199725780522e-10,2.736882356426768e-09,5.884277608354945e-09,9.249869675692636e-09,1.2835477918693938e-08,1.664243568441888e-08,2.067157085045425e-08,2.4923186368629662e-08,2.9397040808739065e-08,3.409232890225645e-08,3.900766208605763e-08,4.4141049046135705e-08,4.948987626132311e-08,5.505088854700678e-08,6.082016959885e-08,6.67931225365098e-08,7.20468735685275e-08,7.7123908626583e-08,8.211474891459002e-08,8.69822646432263e-08,9.168679895992636e-08,9.618610368573303e-08,1.0043527505214256e-07,1.0438668943795546e-07,1.0798993910612359e-07,1.1119176794059747e-07,1.1393600718317665e-07,1.1616351117035572e-07,1.1781209307017445e-07,1.1881646061906443e-07,1.191081518586985e-07,1.1861547087283825e-07,1.1726342352418243e-07,1.149736531912156e-07,1.1214090646142802e-07,1.084897538985594e-07,1.03839161597631e-07,9.812213692842166e-08,9.126980791651416e-08,8.321141431385657e-08,7.387429866933224e-08,6.31838973993196e-08,5.1063731858263946e-08,3.743539940923642e-08,2.221856449450174e-08,5.330949706087853e-09,-1.331167314365821e-08,-3.379549195149345e-08,-5.6208663252726314e-08,-1.8983230145773718e-08,-4.314825648279661e-09,-2.852058857324102e-09,-3.185069614794982e-09,-2.2572853707860962e-09,-8.576337485296194e-10,-1.6504158347364545e-10,7.953765857957185e-11,1.0505831807450243e-10,1.0042651180724797e-10,2.3023073197962944e-11,-8.242619005613566e-11,-8.889463741175694e-11,-1.7944950106033024e-10,-2.3069733160159539e-10,-2.4244155661331595e-10,-2.0621917844672165e-10,-1.2613421660434528e-10,-8.388213966841945e-11,-7.054561688455237e-11,-2.7974753156534772e-11,3.788341725645198e-12,1.7368971529494952e-11,1.7616703354913768e-11,2.43485002753207e-11,2.3471334412004735e-11,1.425130173578076e-11,5.9561406518015635e-12,3.0830061877185886e-13,-3.4559014507220886e-12,-6.063617159923599e-12,-6.9518442917522605e-12,-6.925470299884e-12,-4.85506125158923e-12,-2.196924410473993e-12,3.199880338145212e-14,3.733299915714716e-12,8.543203006718575e-12,1.3793871109644784e-11,1.851340621080679e-11,2.1425849249576616e-11,2.0951180118387584e-11,1.520531766273293e-11,1.7821046144044016e-11,2.8597185082672967e-11,3.8823576661177675e-11,4.737932471381776e-11,5.2967831076720654e-11,5.411679558787775e-11,4.917821608714538e-11,3.6328388416244056e-11,1.3567906418762576e-11,4.409364927995229e-12,1.219791284510606e-12,-2.744381741454558e-12,-7.590731998708008e-12,-1.3435750291935648e-11,-2.0404840381701e-11,-2.863231898444301e-11,-3.826141577248047e-11,-4.944427337400637e-11,-5.5906194294087075e-11,-6.071721344683025e-11,-6.416789649930624e-11,-6.590390983239789e-11,-6.554528419458004e-11,-6.268641470191848e-11,-5.6896060838070186e-11,-4.7717346454282245e-11,-3.492804294206082e-11,-2.8077318149767174e-11,-2.0565711839436533e-11,-1.256394053726387e-11,-4.266328363178031e-12,4.1091929691634745e-12,1.2321084152369045e-11,2.0104198285317858e-11,2.7169780873157635e-11,3.3643030381675285e-11,4.1470810759774145e-11,4.85463936660883e-11,5.461736740191518e-11,5.941468953449211e-11,6.26526868970003e-11,6.402905558856174e-11,6.322486097424131e-11,5.990453768504588e-11,5.3715889617924385e-11,4.4290089935766824e-11,3.1241681067407886e-11,2.4902918198347643e-11,2.10790532190337e-11,1.7355575733578276e-11,1.3919281661511497e-11,1.0973333739435765e-11,8.737261521027994e-12,7.446961377037707e-12,7.354696495288445e-12,8.729096880676821e-12,1.1855159355173414e-11,1.703424755782139e-11,2.115944908583277e-11,2.074034609798801e-11,2.0200729934781578e-11,1.948812048681494e-11,1.8544303765785895e-11,1.7305331904489122e-11,1.5701523156815623e-11,1.3657461897752863e-11,1.10919986233854e-11,7.918249950893573e-12,4.043598618555276e-12,-6.025997195442541e-13,-2.5309646650733644e-12,-4.319380047842855e-12,-5.926552892056219e-12,-7.308485728844423e-12,-8.418476596264872e-12,-9.207119039302235e-12,-9.622302109867996e-12,-9.609210366800469e-12,-9.110323875864943e-12,-8.06541820975372e-12,-6.41156444808575e-12,-4.787387750063699e-12,-4.355187726901887e-12,-3.747460107379381e-12,-2.9997307817520668e-12,-2.1459167707886397e-12,-1.218743870344602e-12,-2.501642959368285e-13,7.282256726817507e-13,1.6847680469483255e-12,2.587325484915141e-12,3.402863646675733e-12,4.3205747636616956e-12,5.922217783920882e-12,7.545788910144714e-12,9.172728729954115e-12,1.0782714221521807e-11,1.2353270113354083e-11,1.3859380244074196e-11,1.5273098922203494e-11,1.656316228594478e-11,1.7694599662963617e-11,1.8628344930171564e-11,1.9320847873507618e-11,1.9723685547721215e-11,1.978317363615402e-11,1.9439977810522567e-11,1.8628725090700256e-11,1.727761520450004e-11,1.5308031947456116e-11,1.2634154542607169e-11,9.162569000277287e-12,6.318815150593144e-12,6.783216538697881e-12,7.307666857859341e-12,7.8855216569148e-12,8.507236084306657e-12,9.16013358139614e-12],\"type\":\"scatter\"},{\"name\":\"Biomass\",\"x\":[0.0,0.04172461752433936,0.08344923504867872,0.12517385257301808,0.16689847009735745,0.20862308762169682,0.25034770514603616,0.29207232267037553,0.3337969401947149,0.37552155771905427,0.41724617524339364,0.458970792767733,0.5006954102920723,0.5424200278164117,0.5841446453407511,0.6258692628650905,0.6675938803894298,0.7093184979137691,0.7510431154381085,0.7927677329624478,0.8344923504867873,0.8762169680111266,0.917941585535466,0.9596662030598053,1.0013908205841446,1.043115438108484,1.0848400556328235,1.1265646731571628,1.1682892906815021,1.2100139082058414,1.251738525730181,1.2934631432545203,1.3351877607788596,1.376912378303199,1.4186369958275382,1.4603616133518778,1.502086230876217,1.5438108484005564,1.5855354659248957,1.6272600834492352,1.6689847009735745,1.7107093184979139,1.7524339360222532,1.7941585535465925,1.835883171070932,1.8776077885952713,1.9193324061196106,1.96105702364395,2.0027816411682893,2.044506258692629,2.086230876216968,2.1279554937413074,2.169680111265647,2.211404728789986,2.2531293463143256,2.294853963838665,2.3365785813630042,2.3783031988873438,2.420027816411683,2.4617524339360224,2.503477051460362,2.545201668984701,2.5869262865090406,2.6286509040333796,2.670375521557719,2.7121001390820587,2.753824756606398,2.7955493741307373,2.8372739916550764,2.878998609179416,2.9207232267037555,2.9624478442280946,3.004172461752434,3.0458970792767732,3.0876216968011128,3.1293463143254523,3.1710709318497914,3.212795549374131,3.2545201668984705,3.2962447844228095,3.337969401947149,3.379694019471488,3.4214186369958277,3.4631432545201672,3.5048678720445063,3.546592489568846,3.588317107093185,3.6300417246175245,3.671766342141864,3.713490959666203,3.7552155771905427,3.7969401947148818,3.8386648122392213,3.880389429763561,3.9221140472879,3.9638386648122395,4.0055632823365785,4.047287899860918,4.089012517385258,4.130737134909597,4.172461752433936,4.214186369958275,4.255910987482615,4.297635605006954,4.339360222531294,4.381084840055633,4.422809457579972,4.464534075104312,4.506258692628651,4.547983310152991,4.58970792767733,4.631432545201669,4.6731571627260085,4.714881780250348,4.7566063977746875,4.798331015299027,4.840055632823366,4.881780250347705,4.923504867872045,4.965229485396384,5.006954102920724,5.0486787204450625,5.090403337969402,5.132127955493742,5.173852573018081,5.215577190542421,5.257301808066759,5.299026425591099,5.340751043115438,5.382475660639778,5.424200278164117,5.465924895688456,5.507649513212796,5.549374130737135,5.591098748261475,5.632823365785814,5.674547983310153,5.716272600834492,5.757997218358832,5.7997218358831715,5.841446453407511,5.88317107093185,5.924895688456189,5.966620305980529,6.008344923504868,6.050069541029208,6.0917941585535464,6.133518776077886,6.1752433936022255,6.216968011126565,6.258692628650905,6.300417246175244,6.342141863699583,6.383866481223922,6.425591098748262,6.467315716272601,6.509040333796941,6.55076495132128,6.592489568845619,6.634214186369959,6.675938803894298,6.717663421418638,6.759388038942976,6.801112656467316,6.842837273991655,6.884561891515995,6.9262865090403345,6.968011126564673,7.009735744089013,7.051460361613352,7.093184979137692,7.134909596662031,7.17663421418637,7.2183588317107095,7.260083449235049,7.3018080667593885,7.343532684283728,7.385257301808067,7.426981919332406,7.468706536856746,7.510431154381085,7.552155771905425,7.5938803894297635,7.635605006954103,7.677329624478443,7.719054242002782,7.760778859527122,7.80250347705146,7.8442280945758,7.885952712100139,7.927677329624479,7.969401947148818,8.011126564673157,8.052851182197497,8.094575799721836,8.136300417246176,8.178025034770515,8.219749652294855,8.261474269819194,8.303198887343534,8.344923504867872,8.386648122392211,8.42837273991655,8.47009735744089,8.51182197496523,8.55354659248957,8.595271210013909,8.636995827538248,8.678720445062588,8.720445062586927,8.762169680111265,8.803894297635605,8.845618915159944,8.887343532684284,8.929068150208623,8.970792767732963,9.012517385257302,9.054242002781642,9.095966620305981,9.137691237830321,9.17941585535466,9.221140472878998,9.262865090403338,9.304589707927677,9.346314325452017,9.388038942976356,9.429763560500696,9.471488178025036,9.513212795549375,9.554937413073715,9.596662030598054,9.638386648122392,9.680111265646731,9.721835883171071,9.76356050069541,9.80528511821975,9.84700973574409,9.888734353268429,9.930458970792769,9.972183588317108,10.013908205841448,10.055632823365785,10.097357440890125,10.139082058414465,10.180806675938804,10.222531293463144,10.264255910987483,10.305980528511823,10.347705146036162,10.389429763560502,10.431154381084841,10.472878998609179,10.514603616133519,10.556328233657858,10.598052851182198,10.639777468706537,10.681502086230877,10.723226703755216,10.764951321279556,10.806675938803895,10.848400556328235,10.890125173852574,10.931849791376912,10.973574408901252,11.015299026425591,11.05702364394993,11.09874826147427,11.14047287899861,11.18219749652295,11.223922114047289,11.265646731571628,11.307371349095968,11.349095966620306,11.390820584144645,11.432545201668985,11.474269819193324,11.515994436717664,11.557719054242003,11.599443671766343,11.641168289290682,11.682892906815022,11.724617524339362,11.7663421418637,11.808066759388039,11.849791376912378,11.891515994436718,11.933240611961057,11.974965229485397,12.016689847009737,12.058414464534076,12.100139082058416,12.141863699582755,12.183588317107093,12.225312934631432,12.267037552155772,12.308762169680111,12.350486787204451,12.39221140472879,12.43393602225313,12.47566063977747,12.51738525730181,12.559109874826149,12.600834492350488,12.642559109874826,12.684283727399166,12.726008344923505,12.767732962447845,12.809457579972184,12.851182197496524,12.892906815020863,12.934631432545203,12.976356050069542,13.018080667593882,13.05980528511822,13.10152990264256,13.143254520166899,13.184979137691238,13.226703755215578,13.268428372739917,13.310152990264257,13.351877607788596,13.393602225312936,13.435326842837275,13.477051460361613,13.518776077885953,13.560500695410292,13.602225312934632,13.643949930458971,13.68567454798331,13.72739916550765,13.76912378303199,13.81084840055633,13.852573018080669,13.894297635605007,13.936022253129346,13.977746870653686,14.019471488178025,14.061196105702365,14.102920723226704,14.144645340751044,14.186369958275383,14.228094575799723,14.269819193324063,14.311543810848402,14.35326842837274,14.39499304589708,14.436717663421419,14.478442280945758,14.520166898470098,14.561891515994438,14.603616133518777,14.645340751043117,14.687065368567456,14.728789986091796,14.770514603616133,14.812239221140473,14.853963838664813,14.895688456189152,14.937413073713492,14.979137691237831,15.02086230876217,15.06258692628651,15.10431154381085,15.14603616133519,15.187760778859527,15.229485396383867,15.271210013908206,15.312934631432546,15.354659248956885,15.396383866481225,15.438108484005564,15.479833101529904,15.521557719054243,15.563282336578583,15.60500695410292,15.64673157162726,15.6884561891516,15.73018080667594,15.771905424200279,15.813630041724618,15.855354659248958,15.897079276773297,15.938803894297637,15.980528511821976,16.022253129346314,16.063977746870655,16.105702364394993,16.147426981919335,16.189151599443672,16.230876216968014,16.27260083449235,16.31432545201669,16.35605006954103,16.39777468706537,16.43949930458971,16.481223922114047,16.52294853963839,16.564673157162726,16.606397774687068,16.648122392211405,16.689847009735743,16.731571627260085,16.773296244784422,16.815020862308764,16.8567454798331,16.898470097357443,16.94019471488178,16.98191933240612,17.02364394993046,17.0653685674548,17.10709318497914,17.148817802503476,17.190542420027818,17.232267037552155,17.273991655076497,17.315716272600834,17.357440890125176,17.399165507649514,17.440890125173855,17.482614742698193,17.52433936022253,17.56606397774687,17.60778859527121,17.64951321279555,17.69123783031989,17.73296244784423,17.774687065368568,17.81641168289291,17.858136300417247,17.899860917941588,17.941585535465926,17.983310152990263,18.025034770514605,18.066759388038943,18.108484005563284,18.15020862308762,18.191933240611963,18.2336578581363,18.275382475660642,18.31710709318498,18.35883171070932,18.40055632823366,18.442280945757997,18.484005563282338,18.525730180806676,18.567454798331017,18.609179415855355,18.650904033379696,18.692628650904034,18.734353268428375,18.776077885952713,18.81780250347705,18.859527121001392,18.90125173852573,18.94297635605007,18.98470097357441,19.02642559109875,19.068150208623088,19.10987482614743,19.151599443671767,19.19332406119611,19.235048678720446,19.276773296244784,19.318497913769125,19.360222531293463,19.401947148817804,19.443671766342142,19.485396383866483,19.52712100139082,19.568845618915162,19.6105702364395,19.65229485396384,19.69401947148818,19.735744089012517,19.777468706536858,19.819193324061196,19.860917941585537,19.902642559109875,19.944367176634216,19.986091794158554,20.027816411682895,20.069541029207233,20.11126564673157,20.152990264255912,20.19471488178025,20.23643949930459,20.27816411682893,20.31988873435327,20.361613351877608,20.40333796940195,20.445062586926287,20.48678720445063,20.528511821974966,20.570236439499304,20.611961057023645,20.653685674547983,20.695410292072324,20.737134909596662,20.778859527121003,20.82058414464534,20.862308762169683,20.90403337969402,20.945757997218358,20.9874826147427,21.029207232267037,21.07093184979138,21.112656467315716,21.154381084840058,21.196105702364395,21.237830319888737,21.279554937413074,21.321279554937416,21.363004172461753,21.40472878998609,21.446453407510432,21.48817802503477,21.52990264255911,21.57162726008345,21.61335187760779,21.65507649513213,21.69680111265647,21.738525730180807,21.78025034770515,21.821974965229487,21.863699582753824,21.905424200278166,21.947148817802503,21.988873435326845,22.030598052851182,22.072322670375524,22.11404728789986,22.155771905424203,22.19749652294854,22.23922114047288,22.28094575799722,22.322670375521557,22.3643949930459,22.406119610570236,22.447844228094578,22.489568845618916,22.531293463143257,22.573018080667595,22.614742698191936,22.656467315716274,22.69819193324061,22.739916550764953,22.78164116828929,22.823365785813632,22.86509040333797,22.90681502086231,22.94853963838665,22.99026425591099,23.031988873435328,23.073713490959666,23.115438108484007,23.157162726008345,23.198887343532686,23.240611961057024,23.282336578581365,23.324061196105703,23.365785813630044,23.407510431154382,23.449235048678723,23.49095966620306,23.5326842837274,23.57440890125174,23.616133518776078,23.65785813630042,23.699582753824757,23.741307371349098,23.783031988873436,23.824756606397777,23.866481223922115,23.908205841446456,23.949930458970794,23.99165507649513,24.033379694019473,24.07510431154381,24.116828929068152,24.15855354659249,24.20027816411683,24.24200278164117,24.28372739916551,24.325452016689848,24.367176634214186,24.408901251738527,24.450625869262865,24.492350486787206,24.534075104311544,24.575799721835885,24.617524339360223,24.659248956884564,24.700973574408902,24.742698191933243,24.78442280945758,24.82614742698192,24.86787204450626,24.909596662030598,24.95132127955494,24.993045897079277,25.03477051460362,25.076495132127956,25.118219749652297,25.159944367176635,25.201668984700976,25.243393602225314,25.285118219749652,25.326842837273993,25.36856745479833,25.410292072322672,25.45201668984701,25.49374130737135,25.53546592489569,25.57719054242003,25.61891515994437,25.660639777468706,25.702364394993047,25.744089012517385,25.785813630041726,25.827538247566064,25.869262865090406,25.910987482614743,25.952712100139085,25.994436717663422,26.036161335187764,26.0778859527121,26.11961057023644,26.16133518776078,26.20305980528512,26.24478442280946,26.286509040333797,26.32823365785814,26.369958275382476,26.411682892906818,26.453407510431155,26.495132127955493,26.536856745479835,26.578581363004172,26.620305980528514,26.66203059805285,26.703755215577193,26.74547983310153,26.78720445062587,26.82892906815021,26.87065368567455,26.91237830319889,26.954102920723226,26.995827538247568,27.037552155771905,27.079276773296247,27.121001390820584,27.162726008344926,27.204450625869264,27.246175243393605,27.287899860917943,27.329624478442284,27.37134909596662,27.41307371349096,27.4547983310153,27.49652294853964,27.53824756606398,27.579972183588318,27.62169680111266,27.663421418636997,27.705146036161338,27.746870653685676,27.788595271210013,27.830319888734355,27.872044506258693,27.913769123783034,27.95549374130737,27.997218358831713,28.03894297635605,28.080667593880392,28.12239221140473,28.16411682892907,28.20584144645341,28.247566063977747,28.289290681502088,28.331015299026426,28.372739916550767,28.414464534075105,28.456189151599446,28.497913769123784,28.539638386648125,28.581363004172463,28.623087621696804,28.664812239221142,28.70653685674548,28.74826147426982,28.78998609179416,28.8317107093185,28.873435326842838,28.91515994436718,28.956884561891517,28.99860917941586,29.040333796940196,29.082058414464534,29.123783031988875,29.165507649513213,29.207232267037554,29.248956884561892,29.290681502086233,29.33240611961057,29.374130737134912,29.41585535465925,29.45757997218359,29.49930458970793,29.541029207232267,29.582753824756608,29.624478442280946,29.666203059805287,29.707927677329625,29.749652294853966,29.791376912378304,29.833101529902645,29.874826147426983,29.91655076495132,29.958275382475662,30.0],\"y\":[0.01,0.010430319053099074,0.010879136969203066,0.011347260124454236,0.011835531534511404,0.012344815555081403,0.012876014025761974,0.013430071813108176,0.014007965491782296,0.014610720892146075,0.015239409820456221,0.015895152750903325,0.01657911327525559,0.017292506124119686,0.0180365989720444,0.018812711530838206,0.01962221756215082,0.02046655510750012,0.021347223712739297,0.022265784695129506,0.023223871808920583,0.024223182827029892,0.02526549374409617,0.026352654027090774,0.02748659195621534,0.02866932365512544,0.02990294271025163,0.031189639694030494,0.032531698816953,0.03393150065585627,0.035391533820933366,0.03691438883320785,0.038502770226916755,0.040159497747728784,0.041887510405937786,0.04368987608287772,0.045569791894857506,0.0475305949404393,0.04957576459836191,0.05170893110342826,0.05393388025292935,0.0562545614101229,0.058675092912644625,0.061199772174240524,0.06383307921789516,0.06657968566895578,0.06944446970562057,0.07243251022257725,0.07554911385269168,0.0787998095643292,0.08219036369688021,0.0857267978466478,0.08941538178206518,0.09326266635051209,0.09727547558465334,0.10146092844115144,0.10582645677968092,0.11037979947570438,0.11512904367816226,0.12008261056789991,0.1252492880097182,0.13063824850083094,0.13625904385729315,0.14212165705894367,0.14823648078103857,0.15461436303206147,0.16126662392571664,0.16820505366810728,0.17544197322924918,0.1829902092567732,0.19086315175395208,0.19907477062178702,0.20763961741605977,0.21657289165849836,0.22589042861934036,0.23560875820536864,0.24574510889700332,0.25631746106090414,0.26734455476961694,0.2788459473967637,0.29084202405699866,0.303354056206149,0.3164042196770415,0.33001564985884196,0.344212470547211,0.3590198445881872,0.37446401371313903,0.39057234575222866,0.40737338529528516,0.42489689779036693,0.4431739320454814,0.4622368606054628,0.4821194553259661,0.5028569237497145,0.5244859984127127,0.5470449695232616,0.5705737884481904,0.5951140970186818,0.6207093459218821,0.6474048206481757,0.6752477754054808,0.7042874565014816,0.7345752538425799,0.7661647198550181,0.799111737960558,0.8334745407302734,0.8693138952905208,0.9066931198966518,0.9456782885414334,0.9863382458172627,1.0287448313303906,1.0729728951962412,1.1191005369215323,1.1672091344751643,1.217383582164137,1.2697123503375953,1.3242877108477211,1.3812058344317601,1.4405670023626214,1.502475743653388,1.5670410324664479,1.6343764671747145,1.7046004533843433,1.7778364264984192,1.8542130206222804,1.9338643358022585,2.016930093487766,2.1035559490197366,2.193893634824969,2.2881013178193776,2.386343732239448,2.48879258025387,2.5956266573485682,2.707032292458787,2.823203470188306,2.944342303899413,3.0706591609461378,3.202373157885629,3.3397122976580564,3.482913969599926,3.6322251116038125,3.7879026875684123,3.9502138938934626,4.119436571371812,4.295859485058519,4.479782601575351,4.671517482712382,4.871387266350927,5.07972734765425,5.296885292202479,5.52322068388577,5.759105538477918,6.004923831175794,6.2610717599820065,6.52795604541781,6.805993911936761,7.095611514708873,7.397241788882762,7.7113213833540035,8.038286494729892,8.378566057889435,8.732571988213314,9.100685009282564,9.483231917087508,9.880447740365264,10.292415128004029,10.718952420095995,11.159401652417436,11.612175995325641,12.073659673756135,12.534939038450183,12.968617757874084,13.25799761282148,13.266000002830364,13.222665565533038,13.178612362458294,13.134696011393922,13.090925894928745,13.047301634908042,13.003822746801843,12.960488749134235,12.917299156097082,12.87425348966828,12.831351268817913,12.78859201548524,12.745975253461667,12.703500507986133,12.661167320122349,12.618975213143612,12.57692371028545,12.535012338335495,12.493240624081372,12.451608117434727,12.410114380448347,12.368758918571762,12.327541264060665,12.286460949170747,12.245517507015249,12.204710564935793,12.164039608437102,12.123504177468766,12.08310381198037,12.042838051921509,12.00270653000217,11.962708717272289,11.922844199262245,11.883112519217512,11.843513221931428,11.804045872300723,11.76471008193148,11.72550536628297,11.686431286376026,11.647487405597976,11.608673289702633,11.569988506810303,11.531432625486458,11.493005211637424,11.454705844173155,11.41653409960281,11.378489556714115,11.340571796573371,11.302780402525453,11.265114948716384,11.227574979310305,11.19016010763371,11.15286991946836,11.115704002329176,11.07866194546424,11.041743339854806,11.004947770593871,10.968274801487185,10.931724044871748,10.895295094053857,10.858987543696374,10.822800989818715,10.786735029796855,10.750789260651157,10.714963275199784,10.679256678708448,10.643669072902194,10.608200060774527,10.572849246587408,10.537616235871251,10.50250063691146,10.467502063523709,10.432620120527734,10.397854418898337,10.363204570898844,10.3286701900811,10.294250891285465,10.259946290640825,10.225756005564584,10.191679654762662,10.157716858229504,10.123867237369582,10.090130419370727,10.056506024913674,10.02299367936235,9.989593009380984,9.956303642934088,9.923125209286479,9.890057339003262,9.85709966394984,9.824251817291914,9.791513433495474,9.758884148326809,9.726363588794626,9.693951398044819,9.661647216680915,9.629450685107045,9.597361444998159,9.56537913930004,9.533503412229294,9.501733909273359,9.470070277190494,9.438512164009795,9.407059219031176,9.375711078936503,9.344467397191789,9.313327831582148,9.282292035492947,9.251359663527694,9.22053037150805,9.189803816473809,9.159179656682928,9.128657551611498,9.098237161953762,9.067918149622104,9.037700173194139,9.007582879126996,8.977565948734002,8.947649047614084,8.917831842572546,8.888114001616346,8.858495193949398,8.828975089967862,8.79955336125543,8.77022968057863,8.741003721882105,8.711875149807863,8.68284362479427,8.653908843019012,8.625070482304332,8.596328221583102,8.56768174089305,8.539130721371,8.510674845247095,8.482313795839039,8.454047257546318,8.425874915844439,8.39779645727916,8.36981156946072,8.341919941058075,8.314121261793124,8.286415222434943,8.25880151479402,8.231279831716487,8.203849867078343,8.176511315779697,8.149263858907487,8.122107199942604,8.095041040521776,8.068065079117938,8.041179015173642,8.014382549094677,7.9876753822436894,7.961057216933797,7.934527756422218,7.908086704903881,7.88173376750505,7.855468650276942,7.829291060189348,7.803200705124252,7.777197293869449,7.751280536112163,7.725450142432676,7.699705824297934,7.674047294055176,7.648474272140132,7.622986498898533,7.5975836643100445,7.572265485065886,7.547031678755324,7.521881963860498,7.496816059751232,7.471833686679866,7.446934565776069,7.4221184190416665,7.39738496934546,7.372733940418044,7.348165056846632,7.323678044069878,7.299272628372693,7.27494853688107,7.250705497556906,7.226543239192817,7.202461491406969,7.1784599846378905,7.1545384749146805,7.130696692045928,7.106934357902365,7.083251207585789,7.059646977088711,7.036121403291977,7.012674223962382,6.98930517775028,6.966014004187207,6.942800443683493,6.919664237525873,6.89660512787511,6.8736228577636025,6.850717171093007,6.827887812631846,6.805134528013128,6.782457066046279,6.759855173338171,6.737328597470344,6.71487708762572,6.692500393847537,6.670198267037175,6.647970458952006,6.625816722203232,6.603736810253717,6.581730477415835,6.559797478849308,6.537937570559039,6.516150509392962,6.49443605303987,6.472793960027266,6.4512239897191925,6.429725890944521,6.408299430441815,6.386944371668116,6.365660476811408,6.344447508852036,6.323305231559594,6.302233409489789,6.281231807981328,6.260300193152785,6.2394383318994855,6.218645991890374,6.197922941564894,6.177268950129867,6.156683787556362,6.13616722457658,6.115719032680717,6.095338981329603,6.075026845313347,6.054782398476206,6.034605415199835,6.014495670601018,5.994452940528319,5.974477001558758,5.9545676309944815,5.934724606859418,5.914947707895959,5.895236713561611,5.875591404025679,5.856011560165912,5.836496963565196,5.8170473965081975,5.797662642132281,5.77834249283965,5.759086726484509,5.739895128429531,5.720767484743407,5.701703582198147,5.682703208266348,5.6637661511185,5.644892199620244,5.626081143329686,5.607332772494656,5.5886468780500085,5.570023251614903,5.551461685490088,5.532961972655186,5.5145239067659775,5.496147282920864,5.477831902298122,5.459577555613492,5.441384039455761,5.4232511510938,5.405178688474354,5.387166450219849,5.369214235626191,5.351321844660564,5.333489077959238,5.315715736825359,5.298001623226759,5.280346539793748,5.262750289816924,5.245212677244963,5.227733506682427,5.210312583455891,5.1929497137102665,5.175644703784899,5.158397360895319,5.141207492902518,5.124074908310756,5.106999416265378,5.089980826550632,5.073018949587485,5.056113596431433,5.039264578770321,5.022471708922157,5.005734799832926,4.98905366507441,4.972428118841996,4.955857975952499,4.939343051841969,4.922883162563518,4.906478124545947,4.890127753369349,4.8738318683689394,4.857590287988199,4.841402831273351,4.825269317871083,4.809189568026283,4.793163402579755,4.777190642965959,4.761271111210723,4.745404629928985,4.7295910223225075,4.713830112177607,4.698121723862891,4.682465682326967,4.666861813096188,4.651309942272362,4.635809896530494,4.620361503179988,4.604964591748506,4.5896189892628305,4.5743245247159265,4.559081027665485,4.543888328231738,4.528746257095258,4.513654645494758,4.498613325224901,4.483622128634093,4.468680888622299,4.453789438638831,4.438947612680165,4.424155245287735,4.409412171545738,4.394718227078941,4.380073248050475,4.36547707115965,4.350929533639747,4.336430478377371,4.321979740009477,4.30757715727423,4.293222569668601,4.278915817221379,4.264656740491186,4.250445180564513,4.23628097905375,4.2221639780952085,4.208094020347156,4.194070948987838,4.180094607713513,4.166164840736474,4.152281492783086,4.138444409091803,4.124653435411208,4.110908417998032,4.0972092036151855,4.083555643702941,4.069947583536061,4.056384870941757,4.042867354822638,4.029394884585597,4.015967310140029,4.00258448189608,3.9892462507628648,3.975952468146703,3.96270298594936,3.9494976565662654,3.936336332884756,3.9232188682823006,3.9101451166247396,3.897114932264509,3.8841281700388803,3.8711846852681857,3.8582843337540567,3.845426972554284,3.8326124581178775,3.81984064752948,3.807111398539715,3.7944245693746086,3.781780018733902,3.7691776057893853,3.7566171901832077,3.7440986320262115,3.731621791896246,3.7191865308364918,3.706792710353788,3.694440192416947,3.6821288394550837,3.6698585143559326,3.6576290906915045,3.6454403690670145,3.633292283254956,3.621184687054758,3.609117420687893,3.5970903906733254,3.585103364574788,3.5731562686852163,3.5612489953329707,3.549381346667525,3.5375533087511437,3.5257647201410935,3.5140154456244046,3.502305355768494,3.4906342815187816,3.47900210008205,3.467408680757885,3.4558538833039254,3.44433759274779,3.4328596713204957,3.4214200044290397,3.41001845715161,3.3986549013295706,3.387329211738715,3.376041266757613,3.364790936602424,3.3535780947049543,3.3424026202974506,3.3312643882362765,3.3201632719359733,3.309099149342274,3.298071896628218,3.28708139184635,3.27612751039142,3.2652101364971777,3.254329152145905,3.2434844279794297,3.232675842304047,3.2219032739000926,3.2111666020219376,3.2004657063979938,3.189800467230708,3.179170765196568,3.1685764850457576,3.158017508924108,3.147493717584657,3.137004994050416,3.1265512218476355,3.11613228500581,3.10574806805768,3.0953984560392245,3.0850833344896693,3.074802581079436,3.06455608407578,3.0543437319020605,3.044165411264841,3.034021009319565,3.023910413670562,3.0138335123710465,3.003790193923113,2.993780347277744,2.98380385067913,2.973860599002967,2.963950482740478,2.9540733916984596,2.9442292160727037,2.9344178464480035,2.9246391737981456,2.9148930894859157,2.9051794851127886,2.8954982470115587,2.885849271214865,2.8762324502198378,2.8666476768841704,2.8570948444261126,2.847573846424478,2.838084576818638,2.8286269299085234,2.8192008000584345,2.809806080744129,2.8004426685299015,2.791110459069399,2.7818093483721116,2.772539232803361,2.7633000090843116,2.7540915742919605,2.7449138258591463,2.7357666615745426,2.7266499795826595,2.7175636783838475,2.7085076549902967,2.6994818092626955,2.6904860411088927,2.681520250342856,2.6725843371287192,2.6636782019807885,2.6548017457635344,2.6459548696916015,2.637137475329799,2.6283494645931067,2.6195907397466742,2.6108612017033077,2.602160751527195,2.5934892945589834,2.584846734256045,2.5762329744149297,2.567647919171373,2.55909147300029,2.5505635407157774,2.542064027471116,2.5335928387587656,2.5251498804103716,2.5167350585519683,2.508348273884706,2.4999894372474136,2.4916584555749215,2.483355236127598,2.475079686491355,2.466831714577644,2.4586112286234587,2.4504181371913334,2.442252349169344,2.434113773771107,2.426002320535781,2.4179178973704,2.409860411044334,2.4018297756772107,2.393825901806601,2.385848700292572,2.377898082316526,2.3699739593800375,2.3620762433036955,2.354204846225939,2.3463596806019007,2.3385406592022395,2.3307476929511637,2.322980689274661,2.3152395679126108,2.3075242426712106,2.2998346276545742,2.2921706372632933,2.2845321861929904,2.276919189432884,2.269331562264341,2.261769220259441,2.2542320792795305,2.2467200554737854,2.2392330652777646,2.2317710254119763,2.224333852880428,2.2169214649691917,2.20953377924496,2.202170713553605,2.1948321860187368,2.1875181150402625,2.1802284174005826,2.1729630085900555,2.1657218117073884,2.158504746093269,2.151311731349252,2.1441426873361227],\"type\":\"scatter\"},{\"name\":\"Oxygen\",\"x\":[0.0,0.04172461752433936,0.08344923504867872,0.12517385257301808,0.16689847009735745,0.20862308762169682,0.25034770514603616,0.29207232267037553,0.3337969401947149,0.37552155771905427,0.41724617524339364,0.458970792767733,0.5006954102920723,0.5424200278164117,0.5841446453407511,0.6258692628650905,0.6675938803894298,0.7093184979137691,0.7510431154381085,0.7927677329624478,0.8344923504867873,0.8762169680111266,0.917941585535466,0.9596662030598053,1.0013908205841446,1.043115438108484,1.0848400556328235,1.1265646731571628,1.1682892906815021,1.2100139082058414,1.251738525730181,1.2934631432545203,1.3351877607788596,1.376912378303199,1.4186369958275382,1.4603616133518778,1.502086230876217,1.5438108484005564,1.5855354659248957,1.6272600834492352,1.6689847009735745,1.7107093184979139,1.7524339360222532,1.7941585535465925,1.835883171070932,1.8776077885952713,1.9193324061196106,1.96105702364395,2.0027816411682893,2.044506258692629,2.086230876216968,2.1279554937413074,2.169680111265647,2.211404728789986,2.2531293463143256,2.294853963838665,2.3365785813630042,2.3783031988873438,2.420027816411683,2.4617524339360224,2.503477051460362,2.545201668984701,2.5869262865090406,2.6286509040333796,2.670375521557719,2.7121001390820587,2.753824756606398,2.7955493741307373,2.8372739916550764,2.878998609179416,2.9207232267037555,2.9624478442280946,3.004172461752434,3.0458970792767732,3.0876216968011128,3.1293463143254523,3.1710709318497914,3.212795549374131,3.2545201668984705,3.2962447844228095,3.337969401947149,3.379694019471488,3.4214186369958277,3.4631432545201672,3.5048678720445063,3.546592489568846,3.588317107093185,3.6300417246175245,3.671766342141864,3.713490959666203,3.7552155771905427,3.7969401947148818,3.8386648122392213,3.880389429763561,3.9221140472879,3.9638386648122395,4.0055632823365785,4.047287899860918,4.089012517385258,4.130737134909597,4.172461752433936,4.214186369958275,4.255910987482615,4.297635605006954,4.339360222531294,4.381084840055633,4.422809457579972,4.464534075104312,4.506258692628651,4.547983310152991,4.58970792767733,4.631432545201669,4.6731571627260085,4.714881780250348,4.7566063977746875,4.798331015299027,4.840055632823366,4.881780250347705,4.923504867872045,4.965229485396384,5.006954102920724,5.0486787204450625,5.090403337969402,5.132127955493742,5.173852573018081,5.215577190542421,5.257301808066759,5.299026425591099,5.340751043115438,5.382475660639778,5.424200278164117,5.465924895688456,5.507649513212796,5.549374130737135,5.591098748261475,5.632823365785814,5.674547983310153,5.716272600834492,5.757997218358832,5.7997218358831715,5.841446453407511,5.88317107093185,5.924895688456189,5.966620305980529,6.008344923504868,6.050069541029208,6.0917941585535464,6.133518776077886,6.1752433936022255,6.216968011126565,6.258692628650905,6.300417246175244,6.342141863699583,6.383866481223922,6.425591098748262,6.467315716272601,6.509040333796941,6.55076495132128,6.592489568845619,6.634214186369959,6.675938803894298,6.717663421418638,6.759388038942976,6.801112656467316,6.842837273991655,6.884561891515995,6.9262865090403345,6.968011126564673,7.009735744089013,7.051460361613352,7.093184979137692,7.134909596662031,7.17663421418637,7.2183588317107095,7.260083449235049,7.3018080667593885,7.343532684283728,7.385257301808067,7.426981919332406,7.468706536856746,7.510431154381085,7.552155771905425,7.5938803894297635,7.635605006954103,7.677329624478443,7.719054242002782,7.760778859527122,7.80250347705146,7.8442280945758,7.885952712100139,7.927677329624479,7.969401947148818,8.011126564673157,8.052851182197497,8.094575799721836,8.136300417246176,8.178025034770515,8.219749652294855,8.261474269819194,8.303198887343534,8.344923504867872,8.386648122392211,8.42837273991655,8.47009735744089,8.51182197496523,8.55354659248957,8.595271210013909,8.636995827538248,8.678720445062588,8.720445062586927,8.762169680111265,8.803894297635605,8.845618915159944,8.887343532684284,8.929068150208623,8.970792767732963,9.012517385257302,9.054242002781642,9.095966620305981,9.137691237830321,9.17941585535466,9.221140472878998,9.262865090403338,9.304589707927677,9.346314325452017,9.388038942976356,9.429763560500696,9.471488178025036,9.513212795549375,9.554937413073715,9.596662030598054,9.638386648122392,9.680111265646731,9.721835883171071,9.76356050069541,9.80528511821975,9.84700973574409,9.888734353268429,9.930458970792769,9.972183588317108,10.013908205841448,10.055632823365785,10.097357440890125,10.139082058414465,10.180806675938804,10.222531293463144,10.264255910987483,10.305980528511823,10.347705146036162,10.389429763560502,10.431154381084841,10.472878998609179,10.514603616133519,10.556328233657858,10.598052851182198,10.639777468706537,10.681502086230877,10.723226703755216,10.764951321279556,10.806675938803895,10.848400556328235,10.890125173852574,10.931849791376912,10.973574408901252,11.015299026425591,11.05702364394993,11.09874826147427,11.14047287899861,11.18219749652295,11.223922114047289,11.265646731571628,11.307371349095968,11.349095966620306,11.390820584144645,11.432545201668985,11.474269819193324,11.515994436717664,11.557719054242003,11.599443671766343,11.641168289290682,11.682892906815022,11.724617524339362,11.7663421418637,11.808066759388039,11.849791376912378,11.891515994436718,11.933240611961057,11.974965229485397,12.016689847009737,12.058414464534076,12.100139082058416,12.141863699582755,12.183588317107093,12.225312934631432,12.267037552155772,12.308762169680111,12.350486787204451,12.39221140472879,12.43393602225313,12.47566063977747,12.51738525730181,12.559109874826149,12.600834492350488,12.642559109874826,12.684283727399166,12.726008344923505,12.767732962447845,12.809457579972184,12.851182197496524,12.892906815020863,12.934631432545203,12.976356050069542,13.018080667593882,13.05980528511822,13.10152990264256,13.143254520166899,13.184979137691238,13.226703755215578,13.268428372739917,13.310152990264257,13.351877607788596,13.393602225312936,13.435326842837275,13.477051460361613,13.518776077885953,13.560500695410292,13.602225312934632,13.643949930458971,13.68567454798331,13.72739916550765,13.76912378303199,13.81084840055633,13.852573018080669,13.894297635605007,13.936022253129346,13.977746870653686,14.019471488178025,14.061196105702365,14.102920723226704,14.144645340751044,14.186369958275383,14.228094575799723,14.269819193324063,14.311543810848402,14.35326842837274,14.39499304589708,14.436717663421419,14.478442280945758,14.520166898470098,14.561891515994438,14.603616133518777,14.645340751043117,14.687065368567456,14.728789986091796,14.770514603616133,14.812239221140473,14.853963838664813,14.895688456189152,14.937413073713492,14.979137691237831,15.02086230876217,15.06258692628651,15.10431154381085,15.14603616133519,15.187760778859527,15.229485396383867,15.271210013908206,15.312934631432546,15.354659248956885,15.396383866481225,15.438108484005564,15.479833101529904,15.521557719054243,15.563282336578583,15.60500695410292,15.64673157162726,15.6884561891516,15.73018080667594,15.771905424200279,15.813630041724618,15.855354659248958,15.897079276773297,15.938803894297637,15.980528511821976,16.022253129346314,16.063977746870655,16.105702364394993,16.147426981919335,16.189151599443672,16.230876216968014,16.27260083449235,16.31432545201669,16.35605006954103,16.39777468706537,16.43949930458971,16.481223922114047,16.52294853963839,16.564673157162726,16.606397774687068,16.648122392211405,16.689847009735743,16.731571627260085,16.773296244784422,16.815020862308764,16.8567454798331,16.898470097357443,16.94019471488178,16.98191933240612,17.02364394993046,17.0653685674548,17.10709318497914,17.148817802503476,17.190542420027818,17.232267037552155,17.273991655076497,17.315716272600834,17.357440890125176,17.399165507649514,17.440890125173855,17.482614742698193,17.52433936022253,17.56606397774687,17.60778859527121,17.64951321279555,17.69123783031989,17.73296244784423,17.774687065368568,17.81641168289291,17.858136300417247,17.899860917941588,17.941585535465926,17.983310152990263,18.025034770514605,18.066759388038943,18.108484005563284,18.15020862308762,18.191933240611963,18.2336578581363,18.275382475660642,18.31710709318498,18.35883171070932,18.40055632823366,18.442280945757997,18.484005563282338,18.525730180806676,18.567454798331017,18.609179415855355,18.650904033379696,18.692628650904034,18.734353268428375,18.776077885952713,18.81780250347705,18.859527121001392,18.90125173852573,18.94297635605007,18.98470097357441,19.02642559109875,19.068150208623088,19.10987482614743,19.151599443671767,19.19332406119611,19.235048678720446,19.276773296244784,19.318497913769125,19.360222531293463,19.401947148817804,19.443671766342142,19.485396383866483,19.52712100139082,19.568845618915162,19.6105702364395,19.65229485396384,19.69401947148818,19.735744089012517,19.777468706536858,19.819193324061196,19.860917941585537,19.902642559109875,19.944367176634216,19.986091794158554,20.027816411682895,20.069541029207233,20.11126564673157,20.152990264255912,20.19471488178025,20.23643949930459,20.27816411682893,20.31988873435327,20.361613351877608,20.40333796940195,20.445062586926287,20.48678720445063,20.528511821974966,20.570236439499304,20.611961057023645,20.653685674547983,20.695410292072324,20.737134909596662,20.778859527121003,20.82058414464534,20.862308762169683,20.90403337969402,20.945757997218358,20.9874826147427,21.029207232267037,21.07093184979138,21.112656467315716,21.154381084840058,21.196105702364395,21.237830319888737,21.279554937413074,21.321279554937416,21.363004172461753,21.40472878998609,21.446453407510432,21.48817802503477,21.52990264255911,21.57162726008345,21.61335187760779,21.65507649513213,21.69680111265647,21.738525730180807,21.78025034770515,21.821974965229487,21.863699582753824,21.905424200278166,21.947148817802503,21.988873435326845,22.030598052851182,22.072322670375524,22.11404728789986,22.155771905424203,22.19749652294854,22.23922114047288,22.28094575799722,22.322670375521557,22.3643949930459,22.406119610570236,22.447844228094578,22.489568845618916,22.531293463143257,22.573018080667595,22.614742698191936,22.656467315716274,22.69819193324061,22.739916550764953,22.78164116828929,22.823365785813632,22.86509040333797,22.90681502086231,22.94853963838665,22.99026425591099,23.031988873435328,23.073713490959666,23.115438108484007,23.157162726008345,23.198887343532686,23.240611961057024,23.282336578581365,23.324061196105703,23.365785813630044,23.407510431154382,23.449235048678723,23.49095966620306,23.5326842837274,23.57440890125174,23.616133518776078,23.65785813630042,23.699582753824757,23.741307371349098,23.783031988873436,23.824756606397777,23.866481223922115,23.908205841446456,23.949930458970794,23.99165507649513,24.033379694019473,24.07510431154381,24.116828929068152,24.15855354659249,24.20027816411683,24.24200278164117,24.28372739916551,24.325452016689848,24.367176634214186,24.408901251738527,24.450625869262865,24.492350486787206,24.534075104311544,24.575799721835885,24.617524339360223,24.659248956884564,24.700973574408902,24.742698191933243,24.78442280945758,24.82614742698192,24.86787204450626,24.909596662030598,24.95132127955494,24.993045897079277,25.03477051460362,25.076495132127956,25.118219749652297,25.159944367176635,25.201668984700976,25.243393602225314,25.285118219749652,25.326842837273993,25.36856745479833,25.410292072322672,25.45201668984701,25.49374130737135,25.53546592489569,25.57719054242003,25.61891515994437,25.660639777468706,25.702364394993047,25.744089012517385,25.785813630041726,25.827538247566064,25.869262865090406,25.910987482614743,25.952712100139085,25.994436717663422,26.036161335187764,26.0778859527121,26.11961057023644,26.16133518776078,26.20305980528512,26.24478442280946,26.286509040333797,26.32823365785814,26.369958275382476,26.411682892906818,26.453407510431155,26.495132127955493,26.536856745479835,26.578581363004172,26.620305980528514,26.66203059805285,26.703755215577193,26.74547983310153,26.78720445062587,26.82892906815021,26.87065368567455,26.91237830319889,26.954102920723226,26.995827538247568,27.037552155771905,27.079276773296247,27.121001390820584,27.162726008344926,27.204450625869264,27.246175243393605,27.287899860917943,27.329624478442284,27.37134909596662,27.41307371349096,27.4547983310153,27.49652294853964,27.53824756606398,27.579972183588318,27.62169680111266,27.663421418636997,27.705146036161338,27.746870653685676,27.788595271210013,27.830319888734355,27.872044506258693,27.913769123783034,27.95549374130737,27.997218358831713,28.03894297635605,28.080667593880392,28.12239221140473,28.16411682892907,28.20584144645341,28.247566063977747,28.289290681502088,28.331015299026426,28.372739916550767,28.414464534075105,28.456189151599446,28.497913769123784,28.539638386648125,28.581363004172463,28.623087621696804,28.664812239221142,28.70653685674548,28.74826147426982,28.78998609179416,28.8317107093185,28.873435326842838,28.91515994436718,28.956884561891517,28.99860917941586,29.040333796940196,29.082058414464534,29.123783031988875,29.165507649513213,29.207232267037554,29.248956884561892,29.290681502086233,29.33240611961057,29.374130737134912,29.41585535465925,29.45757997218359,29.49930458970793,29.541029207232267,29.582753824756608,29.624478442280946,29.666203059805287,29.707927677329625,29.749652294853966,29.791376912378304,29.833101529902645,29.874826147426983,29.91655076495132,29.958275382475662,30.0],\"y\":[0.0755,0.07549999091690655,0.07549999052606346,0.07549999011840913,0.07549998969320945,0.07549998924971185,0.07549998878713099,0.07549998830464406,0.07549998780140077,0.07549998727650781,0.07549998672903191,0.0754999861579974,0.07549998556239113,0.0754999849411553,0.07549998429318612,0.07549998361733447,0.07549998291240415,0.07549998217714303,0.07549998141024541,0.07549998061035183,0.07549997977603974,0.07549997890583085,0.0754999779981788,0.07549997705147327,0.07549997606403534,0.07549997503410959,0.07549997395987315,0.07549997283941874,0.07549997167075757,0.07549997045181701,0.07549996918043039,0.07549996785434225,0.07549996647119797,0.07549996502854255,0.07549996352381717,0.07549996195435098,0.07549996031736067,0.07549995860994105,0.07549995682906314,0.07549995497156652,0.07549995303415523,0.07549995101339126,0.07549994890568953,0.07549994670730929,0.07549994441435097,0.07549994202274816,0.0754999395282537,0.0754999369264464,0.07549993421270829,0.0754999313822277,0.07549992842998561,0.07549992535073821,0.07549992213902737,0.07549991878915625,0.07549991529518837,0.07549991165092813,0.07549990784989917,0.07549990388536332,0.07549989975029393,0.0754998954373651,0.07549989093893082,0.07549988624700146,0.07549988135326538,0.07549987624904314,0.07549987092529163,0.07549986537257347,0.07549985958103954,0.07549985354043401,0.07549984724003983,0.07549984066870011,0.07549983381476877,0.07549982666609605,0.07549981921002692,0.07549981143334385,0.07549980332227715,0.0754997948624544,0.07549978603889661,0.07549977683597225,0.07549976723739055,0.0754997572261516,0.0754997467845373,0.07549973589406139,0.07549972453545337,0.07549971268861094,0.07549970033257533,0.07549968744548675,0.07549967400455022,0.075499659985996,0.07549964536503546,0.07549963011582385,0.07549961421140768,0.07549959762368687,0.07549958032334986,0.07549956227984395,0.07549954346129545,0.07549952383448688,0.07549950336477383,0.07549948201604983,0.07549945975065271,0.0754994365293362,0.07549941231113402,0.07549938705337456,0.07549936071157352,0.0754993332393666,0.07549930458836926,0.07549927470819323,0.07549924354628092,0.07549921104787875,0.07549917715587601,0.07549914181078868,0.07549910495057521,0.07549906651061972,0.07549902642353915,0.0754989846191538,0.07549894102429731,0.0754988955627626,0.07549884815512344,0.07549879871865084,0.07549874716714722,0.07549869341083285,0.07549863735619243,0.0754985789058322,0.07549851795833822,0.07549845440810564,0.07549838814520733,0.07549831905519859,0.07549824701899371,0.07549817191265196,0.07549809360725808,0.07549801196869879,0.07549792685754143,0.07549783812881551,0.07549774563188046,0.07549764921023468,0.07549754870135869,0.07549744393658665,0.0754973347409036,0.07549722093293329,0.07549710232465712,0.07549697872160263,0.0754968499224326,0.07549671571946909,0.07549657589806905,0.07549643023769595,0.0754962785109521,0.07549612048557583,0.07549595592293266,0.07549578458161656,0.07549560621446721,0.07549542057257733,0.07549522741027412,0.07549502648238629,0.07549481755068821,0.07549460038538498,0.0754943747749688,0.07549414053627654,0.07549389752447067,0.07549364565158348,0.07549338491428896,0.07549311542064854,0.07549283748111028,0.07549255157522906,0.07549225881641083,0.07549196069453856,0.075491659893491,0.0754913608420172,0.07549107151791713,0.07549080633614054,0.07549059474213661,0.07549050433067939,0.07549073180734517,0.07549209899018004,0.07549822980510788,0.07550201646181375,0.07550209777001614,0.07550209179781224,0.07550208483890945,0.07550207789186711,0.07550207096759871,0.07550206406625465,0.07550205718802828,0.07550205033254742,0.07550204350001395,0.07550203669028223,0.0755020299031965,0.07550202313872631,0.07550201639680346,0.07550200967732729,0.07550200298023972,0.07550199630548284,0.07550198965299029,0.07550198302269572,0.07550197641450213,0.07550196982829646,0.07550196326404064,0.07550195672166106,0.0755019502010841,0.07550194370223626,0.07550193722504855,0.07550193076944511,0.07550192433535273,0.07550191792269817,0.07550191153140821,0.07550190516142646,0.0755018988126672,0.07550189248506546,0.07550188617854864,0.07550187989304438,0.0755018736284837,0.07550186738480531,0.07550186116193211,0.07550185495979454,0.07550184877832344,0.07550184261745008,0.07550183647710615,0.07550183035722274,0.07550182425772876,0.07550181817855908,0.07550181211964646,0.07550180608092406,0.0755018000623254,0.07550179406378439,0.07550178808523367,0.0755017821266017,0.07550177618782676,0.07550177026884328,0.07550176436958599,0.0755017584899899,0.07550175262999033,0.07550174678952064,0.07550174096850769,0.07550173516689244,0.07550172938461003,0.07550172362159574,0.07550171787778508,0.07550171215311371,0.07550170644751901,0.07550170076094338,0.0755016950933197,0.07550168944458531,0.07550168381467783,0.0755016782035351,0.07550167261109525,0.0755016670372929,0.07550166148205205,0.07550165594532313,0.0755016504270443,0.07550164492715405,0.07550163944559099,0.07550163398229395,0.075501628537202,0.07550162311025442,0.07550161770139065,0.07550161231055039,0.0755016069376736,0.07550160158270391,0.07550159624557921,0.07550159092624016,0.07550158562462767,0.07550158034068281,0.07550157507434697,0.07550156982556165,0.07550156459426864,0.07550155938040992,0.07550155418392766,0.07550154900476432,0.07550154384285455,0.07550153869814501,0.07550153357057948,0.07550152846010083,0.07550152336665207,0.07550151829017644,0.07550151323061736,0.07550150818791847,0.07550150316202353,0.07550149815287659,0.07550149316042183,0.07550148818460393,0.07550148322536747,0.0755014782826571,0.07550147335641785,0.07550146844659489,0.0755014635531336,0.07550145867597959,0.07550145381507861,0.07550144897037665,0.07550144414181988,0.07550143932935466,0.07550143453292665,0.07550142975247917,0.07550142498796222,0.0755014202393227,0.07550141550650771,0.07550141078946457,0.07550140608814075,0.07550140140248396,0.07550139673244204,0.07550139207796305,0.07550138743899527,0.07550138281548545,0.07550137820737969,0.07550137361462977,0.07550136903718455,0.07550136447499307,0.07550135992800454,0.07550135539616835,0.07550135087943408,0.07550134637775142,0.0755013418910703,0.0755013374193408,0.07550133296251313,0.07550132852053772,0.07550132409336514,0.07550131968094613,0.07550131528323158,0.07550131090017256,0.07550130653172032,0.07550130217782623,0.07550129783844184,0.07550129351351731,0.07550128920300521,0.07550128490685792,0.0755012806250276,0.07550127635746649,0.07550127210412706,0.07550126786496186,0.07550126363992364,0.07550125942896527,0.07550125523203977,0.07550125104910031,0.0755012468801002,0.07550124272499288,0.07550123858373198,0.0755012344562712,0.07550123034256444,0.0755012262425657,0.07550122215622912,0.07550121808350901,0.07550121402436148,0.0755012099787473,0.07550120594661526,0.07550120192792037,0.07550119792261781,0.07550119393066289,0.07550118995201105,0.07550118598661788,0.07550118203443913,0.07550117809543064,0.07550117416954844,0.07550117025674863,0.0755011663569875,0.07550116247022148,0.07550115859640709,0.075501154735501,0.07550115088746001,0.07550114705224108,0.07550114322980125,0.07550113942009773,0.07550113562309216,0.0755011318387416,0.07550112806700172,0.07550112430783044,0.07550112056118588,0.07550111682702627,0.07550111310530998,0.07550110939599552,0.07550110569904157,0.0755011020144069,0.07550109834205046,0.07550109468193132,0.07550109103400869,0.07550108739824193,0.07550108377459051,0.07550108016301409,0.075501076563473,0.07550107297592697,0.07550106940033587,0.07550106583665989,0.07550106228485938,0.07550105874489481,0.07550105521672681,0.07550105170031612,0.07550104819562363,0.07550104470261038,0.0755010412212375,0.07550103775146631,0.07550103429325823,0.07550103084657483,0.07550102741137782,0.07550102398762902,0.07550102057528761,0.07550101717431709,0.0755010137846801,0.07550101040633887,0.07550100703925579,0.07550100368339334,0.07550100033871414,0.07550099700518093,0.07550099368275658,0.07550099037140405,0.07550098707108649,0.07550098378176709,0.07550098050340921,0.07550097723597632,0.075500973979432,0.07550097073373996,0.07550096749886359,0.07550096427476712,0.0755009610614146,0.0755009578587702,0.0755009546667982,0.07550095148546296,0.07550094831472899,0.0755009451545609,0.07550094200492342,0.07550093886578138,0.07550093573709973,0.07550093261884354,0.07550092951097796,0.07550092641346827,0.07550092332627985,0.0755009202493783,0.07550091718273332,0.07550091412630754,0.07550091108006693,0.07550090804397758,0.07550090501800565,0.07550090200211745,0.07550089899627943,0.07550089600045812,0.07550089301462014,0.0755008900387323,0.07550088707276145,0.07550088411667459,0.07550088117043885,0.0755008782340214,0.07550087530738964,0.07550087239051091,0.07550086948335244,0.07550086658588219,0.0755008636980679,0.07550086081987747,0.07550085795127888,0.07550085509224023,0.07550085224272973,0.07550084940271569,0.07550084657216652,0.07550084375105078,0.07550084093933708,0.0755008381369942,0.07550083534399098,0.07550083256029638,0.07550082978587948,0.0755008270207081,0.07550082426474686,0.0755008215179695,0.07550081878034534,0.07550081605184378,0.0755008133324343,0.07550081062208651,0.07550080792077007,0.07550080522845477,0.07550080254511046,0.07550079987070711,0.07550079720521474,0.0755007945486035,0.07550079190084362,0.07550078926190538,0.07550078663175921,0.07550078401037556,0.07550078139772504,0.07550077879377953,0.0755007761985189,0.07550077361190624,0.07550077103391276,0.07550076846450976,0.07550076590366867,0.07550076335136098,0.07550076080755831,0.07550075827223238,0.07550075574535499,0.07550075322689806,0.0755007507168336,0.07550074821513372,0.07550074572177065,0.07550074323671668,0.07550074075994426,0.07550073829142585,0.07550073583113409,0.07550073337904167,0.07550073093512064,0.0755007284993445,0.07550072607168624,0.07550072365211895,0.07550072124061581,0.0755007188371501,0.07550071644169518,0.07550071405422454,0.07550071167471176,0.07550070930313048,0.07550070693945447,0.07550070458365761,0.07550070223571383,0.0755006998955972,0.07550069756328184,0.075500695238742,0.07550069292195205,0.07550069061288638,0.07550068831150342,0.07550068601778928,0.07550068373171898,0.07550068145326683,0.07550067918240723,0.07550067691911468,0.07550067466336369,0.07550067241512888,0.0755006701743849,0.07550066794110648,0.07550066571526841,0.07550066349684552,0.07550066128581275,0.07550065908214502,0.07550065688581739,0.07550065469680493,0.07550065251508277,0.0755006503406261,0.07550064817342567,0.07550064601344751,0.07550064386066532,0.07550064171505502,0.07550063957659259,0.07550063744525407,0.07550063532101563,0.07550063320385347,0.07550063109374391,0.07550062899066334,0.0755006268945882,0.07550062480549503,0.07550062272336047,0.07550062064816121,0.07550061857987402,0.07550061651847577,0.07550061446394339,0.0755006124162539,0.07550061037539281,0.07550060834133393,0.07550060631405289,0.07550060429352748,0.07550060227973555,0.07550060027265512,0.07550059827226431,0.07550059627854135,0.07550059429146454,0.07550059231101235,0.07550059033716336,0.07550058836989623,0.07550058640918979,0.07550058445502292,0.07550058250737467,0.07550058056730126,0.07550057863228554,0.07550057670401605,0.07550057478221282,0.07550057286678448,0.07550057095773105,0.0755005690550429,0.07550056715870229,0.07550056526868822,0.0755005633849643,0.07550056150752937,0.07550055963635682,0.07550055777142223,0.07550055591270952,0.07550055406018899,0.07550055221384053,0.07550055037364271,0.075500548539574,0.07550054671162017,0.07550054488975906,0.07550054307396678,0.07550054126422479,0.07550053946051274,0.07550053766281115,0.07550053587110148,0.07550053408536293,0.0755005323055756,0.07550053053171932,0.0755005287637741,0.07550052700172004,0.07550052524553785,0.07550052349520789,0.07550052175071087,0.07550052001202698,0.07550051827913776,0.07550051655202447,0.0755005148306666,0.07550051311504487,0.07550051140514007,0.0755005097009331,0.07550050800240499,0.07550050630953681,0.07550050462230977,0.07550050294070453,0.07550050126470237,0.07550049959428502,0.07550049792943399,0.07550049627013085,0.07550049461635731,0.07550049296809513,0.07550049132532619,0.07550048968803244,0.07550048805619294,0.07550048642979047,0.07550048480880775,0.07550048319322679,0.0755004815830297,0.07550047997819863,0.07550047837871585,0.07550047678456363,0.0755004751957244,0.07550047361217863,0.07550047203390971,0.07550047046090029,0.07550046889313289,0.07550046733059007,0.07550046577325448,0.07550046422110877,0.07550046267413572,0.07550046113231812,0.07550045959563796,0.07550045806407872,0.07550045653762331,0.07550045501625474,0.07550045349995606,0.07550045198871037,0.07550045048250084,0.0755004489813107,0.07550044748512316,0.0755004459939214,0.07550044450768895,0.07550044302640924,0.07550044155006577,0.07550044007864211,0.07550043861212183,0.07550043715048863,0.07550043569372622,0.07550043424181838,0.07550043279474894,0.07550043135250181,0.07550042991506051,0.07550042848240919,0.075500427054532,0.07550042563141303,0.07550042421303643,0.0755004227993864,0.0755004213904472,0.07550041998620316,0.07550041858663864,0.07550041719173806,0.07550041580148592,0.07550041441586659,0.07550041303486453,0.07550041165846454,0.0755004102866513,0.07550040891940957,0.07550040755672413,0.07550040619857984,0.0755004048449616,0.07550040349585437,0.07550040215124314,0.075500400811113,0.07550039947544906,0.07550039814423458,0.07550039681745607,0.07550039549509878,0.07550039417714793,0.07550039286358882,0.07550039155440683,0.07550039024958732,0.07550038894911579,0.07550038765297769,0.07550038636115859,0.0755003850736441,0.07550038379042054,0.07550038251147477,0.0755003812367913,0.07550037996635607,0.075500378700155,0.0755003774381741,0.07550037618039945,0.07550037492681715,0.07550037367741334,0.07550037243217426,0.0755003711910862,0.07550036995413342,0.07550036872129676,0.07550036749256826,0.07550036626793422,0.07550036504738096,0.07550036383089485,0.07550036261846234,0.07550036141006986,0.07550036020570393,0.07550035900535111,0.075500357808998,0.07550035661663125,0.07550035542823753,0.0755003542438036,0.07550035306331622,0.07550035188676223,0.0755003507141285,0.07550034954540195,0.07550034838056956,0.0755003472196183,0.07550034606253593,0.0755003449093107,0.07550034375992844,0.07550034261437641,0.07550034147264191,0.07550034033471228],\"type\":\"scatter\"}],                        {\"template\":{\"data\":{\"histogram2dcontour\":[{\"type\":\"histogram2dcontour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"choropleth\":[{\"type\":\"choropleth\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"histogram2d\":[{\"type\":\"histogram2d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmap\":[{\"type\":\"heatmap\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmapgl\":[{\"type\":\"heatmapgl\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"contourcarpet\":[{\"type\":\"contourcarpet\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"contour\":[{\"type\":\"contour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"surface\":[{\"type\":\"surface\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"mesh3d\":[{\"type\":\"mesh3d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"parcoords\":[{\"type\":\"parcoords\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolargl\":[{\"type\":\"scatterpolargl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"scattergeo\":[{\"type\":\"scattergeo\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolar\":[{\"type\":\"scatterpolar\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"scattergl\":[{\"type\":\"scattergl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatter3d\":[{\"type\":\"scatter3d\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattermapbox\":[{\"type\":\"scattermapbox\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterternary\":[{\"type\":\"scatterternary\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattercarpet\":[{\"type\":\"scattercarpet\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}]},\"layout\":{\"autotypenumbers\":\"strict\",\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"hovermode\":\"closest\",\"hoverlabel\":{\"align\":\"left\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"bgcolor\":\"#E5ECF6\",\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"ternary\":{\"bgcolor\":\"#E5ECF6\",\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]]},\"xaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"yaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"geo\":{\"bgcolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"subunitcolor\":\"white\",\"showland\":true,\"showlakes\":true,\"lakecolor\":\"white\"},\"title\":{\"x\":0.05},\"mapbox\":{\"style\":\"light\"}}},\"title\":{\"text\":\"Simulation of a generic model of Monod-Herbet under aerobic conditions\"},\"xaxis\":{\"title\":{\"text\":\"time (h)\"}},\"yaxis\":{\"title\":{\"text\":\"Concentration (g\\u002fL)\"}}},                        {\"responsive\": true}                    ).then(function(){\n","                            \n","var gd = document.getElementById('e12d655d-7666-4f6b-96b9-fff07e0c2bd9');\n","var x = new MutationObserver(function (mutations, observer) {{\n","        var display = window.getComputedStyle(gd).display;\n","        if (!display || display === 'none') {{\n","            console.log([gd, 'removed!']);\n","            Plotly.purge(gd);\n","            observer.disconnect();\n","        }}\n","}});\n","\n","// Listen for the removal of the full notebook cells\n","var notebookContainer = gd.closest('#notebook-container');\n","if (notebookContainer) {{\n","    x.observe(notebookContainer, {childList: true});\n","}}\n","\n","// Listen for the clearing of the current output cell\n","var outputEl = gd.closest('.output');\n","if (outputEl) {{\n","    x.observe(outputEl, {childList: true});\n","}}\n","\n","                        })                };                            </script>        </div>\n","</body>\n","</html>"]},"metadata":{}},{"output_type":"display_data","data":{"text/html":["<html>\n","<head><meta charset=\"utf-8\" /></head>\n","<body>\n","    <div>            <script src=\"https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.5/MathJax.js?config=TeX-AMS-MML_SVG\"></script><script type=\"text/javascript\">if (window.MathJax && window.MathJax.Hub && window.MathJax.Hub.Config) {window.MathJax.Hub.Config({SVG: {font: \"STIX-Web\"}});}</script>                <script type=\"text/javascript\">window.PlotlyConfig = {MathJaxConfig: 'local'};</script>\n","        <script charset=\"utf-8\" src=\"https://cdn.plot.ly/plotly-2.35.2.min.js\"></script>                <div id=\"f26b81d1-ffd3-409c-a394-3509efecd9fa\" class=\"plotly-graph-div\" style=\"height:525px; width:100%;\"></div>            <script type=\"text/javascript\">                                    window.PLOTLYENV=window.PLOTLYENV || {};                                    if (document.getElementById(\"f26b81d1-ffd3-409c-a394-3509efecd9fa\")) {                    Plotly.newPlot(                        \"f26b81d1-ffd3-409c-a394-3509efecd9fa\",                        [{\"name\":\"Temperature\",\"x\":[0.0,0.04172461752433936,0.08344923504867872,0.12517385257301808,0.16689847009735745,0.20862308762169682,0.25034770514603616,0.29207232267037553,0.3337969401947149,0.37552155771905427,0.41724617524339364,0.458970792767733,0.5006954102920723,0.5424200278164117,0.5841446453407511,0.6258692628650905,0.6675938803894298,0.7093184979137691,0.7510431154381085,0.7927677329624478,0.8344923504867873,0.8762169680111266,0.917941585535466,0.9596662030598053,1.0013908205841446,1.043115438108484,1.0848400556328235,1.1265646731571628,1.1682892906815021,1.2100139082058414,1.251738525730181,1.2934631432545203,1.3351877607788596,1.376912378303199,1.4186369958275382,1.4603616133518778,1.502086230876217,1.5438108484005564,1.5855354659248957,1.6272600834492352,1.6689847009735745,1.7107093184979139,1.7524339360222532,1.7941585535465925,1.835883171070932,1.8776077885952713,1.9193324061196106,1.96105702364395,2.0027816411682893,2.044506258692629,2.086230876216968,2.1279554937413074,2.169680111265647,2.211404728789986,2.2531293463143256,2.294853963838665,2.3365785813630042,2.3783031988873438,2.420027816411683,2.4617524339360224,2.503477051460362,2.545201668984701,2.5869262865090406,2.6286509040333796,2.670375521557719,2.7121001390820587,2.753824756606398,2.7955493741307373,2.8372739916550764,2.878998609179416,2.9207232267037555,2.9624478442280946,3.004172461752434,3.0458970792767732,3.0876216968011128,3.1293463143254523,3.1710709318497914,3.212795549374131,3.2545201668984705,3.2962447844228095,3.337969401947149,3.379694019471488,3.4214186369958277,3.4631432545201672,3.5048678720445063,3.546592489568846,3.588317107093185,3.6300417246175245,3.671766342141864,3.713490959666203,3.7552155771905427,3.7969401947148818,3.8386648122392213,3.880389429763561,3.9221140472879,3.9638386648122395,4.0055632823365785,4.047287899860918,4.089012517385258,4.130737134909597,4.172461752433936,4.214186369958275,4.255910987482615,4.297635605006954,4.339360222531294,4.381084840055633,4.422809457579972,4.464534075104312,4.506258692628651,4.547983310152991,4.58970792767733,4.631432545201669,4.6731571627260085,4.714881780250348,4.7566063977746875,4.798331015299027,4.840055632823366,4.881780250347705,4.923504867872045,4.965229485396384,5.006954102920724,5.0486787204450625,5.090403337969402,5.132127955493742,5.173852573018081,5.215577190542421,5.257301808066759,5.299026425591099,5.340751043115438,5.382475660639778,5.424200278164117,5.465924895688456,5.507649513212796,5.549374130737135,5.591098748261475,5.632823365785814,5.674547983310153,5.716272600834492,5.757997218358832,5.7997218358831715,5.841446453407511,5.88317107093185,5.924895688456189,5.966620305980529,6.008344923504868,6.050069541029208,6.0917941585535464,6.133518776077886,6.1752433936022255,6.216968011126565,6.258692628650905,6.300417246175244,6.342141863699583,6.383866481223922,6.425591098748262,6.467315716272601,6.509040333796941,6.55076495132128,6.592489568845619,6.634214186369959,6.675938803894298,6.717663421418638,6.759388038942976,6.801112656467316,6.842837273991655,6.884561891515995,6.9262865090403345,6.968011126564673,7.009735744089013,7.051460361613352,7.093184979137692,7.134909596662031,7.17663421418637,7.2183588317107095,7.260083449235049,7.3018080667593885,7.343532684283728,7.385257301808067,7.426981919332406,7.468706536856746,7.510431154381085,7.552155771905425,7.5938803894297635,7.635605006954103,7.677329624478443,7.719054242002782,7.760778859527122,7.80250347705146,7.8442280945758,7.885952712100139,7.927677329624479,7.969401947148818,8.011126564673157,8.052851182197497,8.094575799721836,8.136300417246176,8.178025034770515,8.219749652294855,8.261474269819194,8.303198887343534,8.344923504867872,8.386648122392211,8.42837273991655,8.47009735744089,8.51182197496523,8.55354659248957,8.595271210013909,8.636995827538248,8.678720445062588,8.720445062586927,8.762169680111265,8.803894297635605,8.845618915159944,8.887343532684284,8.929068150208623,8.970792767732963,9.012517385257302,9.054242002781642,9.095966620305981,9.137691237830321,9.17941585535466,9.221140472878998,9.262865090403338,9.304589707927677,9.346314325452017,9.388038942976356,9.429763560500696,9.471488178025036,9.513212795549375,9.554937413073715,9.596662030598054,9.638386648122392,9.680111265646731,9.721835883171071,9.76356050069541,9.80528511821975,9.84700973574409,9.888734353268429,9.930458970792769,9.972183588317108,10.013908205841448,10.055632823365785,10.097357440890125,10.139082058414465,10.180806675938804,10.222531293463144,10.264255910987483,10.305980528511823,10.347705146036162,10.389429763560502,10.431154381084841,10.472878998609179,10.514603616133519,10.556328233657858,10.598052851182198,10.639777468706537,10.681502086230877,10.723226703755216,10.764951321279556,10.806675938803895,10.848400556328235,10.890125173852574,10.931849791376912,10.973574408901252,11.015299026425591,11.05702364394993,11.09874826147427,11.14047287899861,11.18219749652295,11.223922114047289,11.265646731571628,11.307371349095968,11.349095966620306,11.390820584144645,11.432545201668985,11.474269819193324,11.515994436717664,11.557719054242003,11.599443671766343,11.641168289290682,11.682892906815022,11.724617524339362,11.7663421418637,11.808066759388039,11.849791376912378,11.891515994436718,11.933240611961057,11.974965229485397,12.016689847009737,12.058414464534076,12.100139082058416,12.141863699582755,12.183588317107093,12.225312934631432,12.267037552155772,12.308762169680111,12.350486787204451,12.39221140472879,12.43393602225313,12.47566063977747,12.51738525730181,12.559109874826149,12.600834492350488,12.642559109874826,12.684283727399166,12.726008344923505,12.767732962447845,12.809457579972184,12.851182197496524,12.892906815020863,12.934631432545203,12.976356050069542,13.018080667593882,13.05980528511822,13.10152990264256,13.143254520166899,13.184979137691238,13.226703755215578,13.268428372739917,13.310152990264257,13.351877607788596,13.393602225312936,13.435326842837275,13.477051460361613,13.518776077885953,13.560500695410292,13.602225312934632,13.643949930458971,13.68567454798331,13.72739916550765,13.76912378303199,13.81084840055633,13.852573018080669,13.894297635605007,13.936022253129346,13.977746870653686,14.019471488178025,14.061196105702365,14.102920723226704,14.144645340751044,14.186369958275383,14.228094575799723,14.269819193324063,14.311543810848402,14.35326842837274,14.39499304589708,14.436717663421419,14.478442280945758,14.520166898470098,14.561891515994438,14.603616133518777,14.645340751043117,14.687065368567456,14.728789986091796,14.770514603616133,14.812239221140473,14.853963838664813,14.895688456189152,14.937413073713492,14.979137691237831,15.02086230876217,15.06258692628651,15.10431154381085,15.14603616133519,15.187760778859527,15.229485396383867,15.271210013908206,15.312934631432546,15.354659248956885,15.396383866481225,15.438108484005564,15.479833101529904,15.521557719054243,15.563282336578583,15.60500695410292,15.64673157162726,15.6884561891516,15.73018080667594,15.771905424200279,15.813630041724618,15.855354659248958,15.897079276773297,15.938803894297637,15.980528511821976,16.022253129346314,16.063977746870655,16.105702364394993,16.147426981919335,16.189151599443672,16.230876216968014,16.27260083449235,16.31432545201669,16.35605006954103,16.39777468706537,16.43949930458971,16.481223922114047,16.52294853963839,16.564673157162726,16.606397774687068,16.648122392211405,16.689847009735743,16.731571627260085,16.773296244784422,16.815020862308764,16.8567454798331,16.898470097357443,16.94019471488178,16.98191933240612,17.02364394993046,17.0653685674548,17.10709318497914,17.148817802503476,17.190542420027818,17.232267037552155,17.273991655076497,17.315716272600834,17.357440890125176,17.399165507649514,17.440890125173855,17.482614742698193,17.52433936022253,17.56606397774687,17.60778859527121,17.64951321279555,17.69123783031989,17.73296244784423,17.774687065368568,17.81641168289291,17.858136300417247,17.899860917941588,17.941585535465926,17.983310152990263,18.025034770514605,18.066759388038943,18.108484005563284,18.15020862308762,18.191933240611963,18.2336578581363,18.275382475660642,18.31710709318498,18.35883171070932,18.40055632823366,18.442280945757997,18.484005563282338,18.525730180806676,18.567454798331017,18.609179415855355,18.650904033379696,18.692628650904034,18.734353268428375,18.776077885952713,18.81780250347705,18.859527121001392,18.90125173852573,18.94297635605007,18.98470097357441,19.02642559109875,19.068150208623088,19.10987482614743,19.151599443671767,19.19332406119611,19.235048678720446,19.276773296244784,19.318497913769125,19.360222531293463,19.401947148817804,19.443671766342142,19.485396383866483,19.52712100139082,19.568845618915162,19.6105702364395,19.65229485396384,19.69401947148818,19.735744089012517,19.777468706536858,19.819193324061196,19.860917941585537,19.902642559109875,19.944367176634216,19.986091794158554,20.027816411682895,20.069541029207233,20.11126564673157,20.152990264255912,20.19471488178025,20.23643949930459,20.27816411682893,20.31988873435327,20.361613351877608,20.40333796940195,20.445062586926287,20.48678720445063,20.528511821974966,20.570236439499304,20.611961057023645,20.653685674547983,20.695410292072324,20.737134909596662,20.778859527121003,20.82058414464534,20.862308762169683,20.90403337969402,20.945757997218358,20.9874826147427,21.029207232267037,21.07093184979138,21.112656467315716,21.154381084840058,21.196105702364395,21.237830319888737,21.279554937413074,21.321279554937416,21.363004172461753,21.40472878998609,21.446453407510432,21.48817802503477,21.52990264255911,21.57162726008345,21.61335187760779,21.65507649513213,21.69680111265647,21.738525730180807,21.78025034770515,21.821974965229487,21.863699582753824,21.905424200278166,21.947148817802503,21.988873435326845,22.030598052851182,22.072322670375524,22.11404728789986,22.155771905424203,22.19749652294854,22.23922114047288,22.28094575799722,22.322670375521557,22.3643949930459,22.406119610570236,22.447844228094578,22.489568845618916,22.531293463143257,22.573018080667595,22.614742698191936,22.656467315716274,22.69819193324061,22.739916550764953,22.78164116828929,22.823365785813632,22.86509040333797,22.90681502086231,22.94853963838665,22.99026425591099,23.031988873435328,23.073713490959666,23.115438108484007,23.157162726008345,23.198887343532686,23.240611961057024,23.282336578581365,23.324061196105703,23.365785813630044,23.407510431154382,23.449235048678723,23.49095966620306,23.5326842837274,23.57440890125174,23.616133518776078,23.65785813630042,23.699582753824757,23.741307371349098,23.783031988873436,23.824756606397777,23.866481223922115,23.908205841446456,23.949930458970794,23.99165507649513,24.033379694019473,24.07510431154381,24.116828929068152,24.15855354659249,24.20027816411683,24.24200278164117,24.28372739916551,24.325452016689848,24.367176634214186,24.408901251738527,24.450625869262865,24.492350486787206,24.534075104311544,24.575799721835885,24.617524339360223,24.659248956884564,24.700973574408902,24.742698191933243,24.78442280945758,24.82614742698192,24.86787204450626,24.909596662030598,24.95132127955494,24.993045897079277,25.03477051460362,25.076495132127956,25.118219749652297,25.159944367176635,25.201668984700976,25.243393602225314,25.285118219749652,25.326842837273993,25.36856745479833,25.410292072322672,25.45201668984701,25.49374130737135,25.53546592489569,25.57719054242003,25.61891515994437,25.660639777468706,25.702364394993047,25.744089012517385,25.785813630041726,25.827538247566064,25.869262865090406,25.910987482614743,25.952712100139085,25.994436717663422,26.036161335187764,26.0778859527121,26.11961057023644,26.16133518776078,26.20305980528512,26.24478442280946,26.286509040333797,26.32823365785814,26.369958275382476,26.411682892906818,26.453407510431155,26.495132127955493,26.536856745479835,26.578581363004172,26.620305980528514,26.66203059805285,26.703755215577193,26.74547983310153,26.78720445062587,26.82892906815021,26.87065368567455,26.91237830319889,26.954102920723226,26.995827538247568,27.037552155771905,27.079276773296247,27.121001390820584,27.162726008344926,27.204450625869264,27.246175243393605,27.287899860917943,27.329624478442284,27.37134909596662,27.41307371349096,27.4547983310153,27.49652294853964,27.53824756606398,27.579972183588318,27.62169680111266,27.663421418636997,27.705146036161338,27.746870653685676,27.788595271210013,27.830319888734355,27.872044506258693,27.913769123783034,27.95549374130737,27.997218358831713,28.03894297635605,28.080667593880392,28.12239221140473,28.16411682892907,28.20584144645341,28.247566063977747,28.289290681502088,28.331015299026426,28.372739916550767,28.414464534075105,28.456189151599446,28.497913769123784,28.539638386648125,28.581363004172463,28.623087621696804,28.664812239221142,28.70653685674548,28.74826147426982,28.78998609179416,28.8317107093185,28.873435326842838,28.91515994436718,28.956884561891517,28.99860917941586,29.040333796940196,29.082058414464534,29.123783031988875,29.165507649513213,29.207232267037554,29.248956884561892,29.290681502086233,29.33240611961057,29.374130737134912,29.41585535465925,29.45757997218359,29.49930458970793,29.541029207232267,29.582753824756608,29.624478442280946,29.666203059805287,29.707927677329625,29.749652294853966,29.791376912378304,29.833101529902645,29.874826147426983,29.91655076495132,29.958275382475662,30.0],\"y\":[30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0,30.0],\"type\":\"scatter\"}],                        {\"template\":{\"data\":{\"histogram2dcontour\":[{\"type\":\"histogram2dcontour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"choropleth\":[{\"type\":\"choropleth\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"histogram2d\":[{\"type\":\"histogram2d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmap\":[{\"type\":\"heatmap\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"heatmapgl\":[{\"type\":\"heatmapgl\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"contourcarpet\":[{\"type\":\"contourcarpet\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"contour\":[{\"type\":\"contour\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"surface\":[{\"type\":\"surface\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"},\"colorscale\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]]}],\"mesh3d\":[{\"type\":\"mesh3d\",\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}],\"scatter\":[{\"fillpattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2},\"type\":\"scatter\"}],\"parcoords\":[{\"type\":\"parcoords\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolargl\":[{\"type\":\"scatterpolargl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"bar\":[{\"error_x\":{\"color\":\"#2a3f5f\"},\"error_y\":{\"color\":\"#2a3f5f\"},\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"bar\"}],\"scattergeo\":[{\"type\":\"scattergeo\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterpolar\":[{\"type\":\"scatterpolar\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"histogram\":[{\"marker\":{\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"histogram\"}],\"scattergl\":[{\"type\":\"scattergl\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatter3d\":[{\"type\":\"scatter3d\",\"line\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattermapbox\":[{\"type\":\"scattermapbox\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scatterternary\":[{\"type\":\"scatterternary\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"scattercarpet\":[{\"type\":\"scattercarpet\",\"marker\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}}}],\"carpet\":[{\"aaxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"baxis\":{\"endlinecolor\":\"#2a3f5f\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"minorgridcolor\":\"white\",\"startlinecolor\":\"#2a3f5f\"},\"type\":\"carpet\"}],\"table\":[{\"cells\":{\"fill\":{\"color\":\"#EBF0F8\"},\"line\":{\"color\":\"white\"}},\"header\":{\"fill\":{\"color\":\"#C8D4E3\"},\"line\":{\"color\":\"white\"}},\"type\":\"table\"}],\"barpolar\":[{\"marker\":{\"line\":{\"color\":\"#E5ECF6\",\"width\":0.5},\"pattern\":{\"fillmode\":\"overlay\",\"size\":10,\"solidity\":0.2}},\"type\":\"barpolar\"}],\"pie\":[{\"automargin\":true,\"type\":\"pie\"}]},\"layout\":{\"autotypenumbers\":\"strict\",\"colorway\":[\"#636efa\",\"#EF553B\",\"#00cc96\",\"#ab63fa\",\"#FFA15A\",\"#19d3f3\",\"#FF6692\",\"#B6E880\",\"#FF97FF\",\"#FECB52\"],\"font\":{\"color\":\"#2a3f5f\"},\"hovermode\":\"closest\",\"hoverlabel\":{\"align\":\"left\"},\"paper_bgcolor\":\"white\",\"plot_bgcolor\":\"#E5ECF6\",\"polar\":{\"bgcolor\":\"#E5ECF6\",\"angularaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"radialaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"ternary\":{\"bgcolor\":\"#E5ECF6\",\"aaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"baxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"},\"caxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\"}},\"coloraxis\":{\"colorbar\":{\"outlinewidth\":0,\"ticks\":\"\"}},\"colorscale\":{\"sequential\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"sequentialminus\":[[0.0,\"#0d0887\"],[0.1111111111111111,\"#46039f\"],[0.2222222222222222,\"#7201a8\"],[0.3333333333333333,\"#9c179e\"],[0.4444444444444444,\"#bd3786\"],[0.5555555555555556,\"#d8576b\"],[0.6666666666666666,\"#ed7953\"],[0.7777777777777778,\"#fb9f3a\"],[0.8888888888888888,\"#fdca26\"],[1.0,\"#f0f921\"]],\"diverging\":[[0,\"#8e0152\"],[0.1,\"#c51b7d\"],[0.2,\"#de77ae\"],[0.3,\"#f1b6da\"],[0.4,\"#fde0ef\"],[0.5,\"#f7f7f7\"],[0.6,\"#e6f5d0\"],[0.7,\"#b8e186\"],[0.8,\"#7fbc41\"],[0.9,\"#4d9221\"],[1,\"#276419\"]]},\"xaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"yaxis\":{\"gridcolor\":\"white\",\"linecolor\":\"white\",\"ticks\":\"\",\"title\":{\"standoff\":15},\"zerolinecolor\":\"white\",\"automargin\":true,\"zerolinewidth\":2},\"scene\":{\"xaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"yaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2},\"zaxis\":{\"backgroundcolor\":\"#E5ECF6\",\"gridcolor\":\"white\",\"linecolor\":\"white\",\"showbackground\":true,\"ticks\":\"\",\"zerolinecolor\":\"white\",\"gridwidth\":2}},\"shapedefaults\":{\"line\":{\"color\":\"#2a3f5f\"}},\"annotationdefaults\":{\"arrowcolor\":\"#2a3f5f\",\"arrowhead\":0,\"arrowwidth\":1},\"geo\":{\"bgcolor\":\"white\",\"landcolor\":\"#E5ECF6\",\"subunitcolor\":\"white\",\"showland\":true,\"showlakes\":true,\"lakecolor\":\"white\"},\"title\":{\"x\":0.05},\"mapbox\":{\"style\":\"light\"}}},\"xaxis\":{\"title\":{\"text\":\"time (h)\"}},\"yaxis\":{\"title\":{\"text\":\"Temperature (C)\"}}},                        {\"responsive\": true}                    ).then(function(){\n","                            \n","var gd = document.getElementById('f26b81d1-ffd3-409c-a394-3509efecd9fa');\n","var x = new MutationObserver(function (mutations, observer) {{\n","        var display = window.getComputedStyle(gd).display;\n","        if (!display || display === 'none') {{\n","            console.log([gd, 'removed!']);\n","            Plotly.purge(gd);\n","            observer.disconnect();\n","        }}\n","}});\n","\n","// Listen for the removal of the full notebook cells\n","var notebookContainer = gd.closest('#notebook-container');\n","if (notebookContainer) {{\n","    x.observe(notebookContainer, {childList: true});\n","}}\n","\n","// Listen for the clearing of the current output cell\n","var outputEl = gd.closest('.output');\n","if (outputEl) {{\n","    x.observe(outputEl, {childList: true});\n","}}\n","\n","                        })                };                            </script>        </div>\n","</body>\n","</html>"]},"metadata":{}}]},{"cell_type":"markdown","source":["# Using the model\n","\n","With this code you are able to test the behaviour of the process in a more simple case when we assume temperature is constant since the generation of metabolic heat is ignored. You can also turn ON the control option and evaluate the dymamics in Temperature. Furthermore, you can try to test different initila conditions, e.g., initial substrate concentrations (remember, these should be realistic values), and study the impact on the dynamics of Biomass."],"metadata":{"id":"V12O4bYt0yB7"}},{"cell_type":"code","source":[],"metadata":{"id":"hZg8TEJy1jWz"},"execution_count":null,"outputs":[]}]}